=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2010-10-12 05:21:02 +0000
+++ drizzled/drizzled.cc	2010-10-14 07:05:23 +0000
@@ -435,17 +435,17 @@
 
   Session *tmp;
 
-  LOCK_thread_count.lock(); // For unlink from list
-
-  for( SessionList::iterator it= getSessionList().begin(); it != getSessionList().end(); ++it )
   {
-    tmp= *it;
-    tmp->killed= Session::KILL_CONNECTION;
-    tmp->scheduler->killSession(tmp);
-    DRIZZLE_CONNECTION_DONE(tmp->thread_id);
-    tmp->lockOnSys();
+    boost::mutex::scoped_lock scoped(LOCK_thread_count);
+    for( SessionList::iterator it= getSessionList().begin(); it != getSessionList().end(); ++it )
+    {
+      tmp= *it;
+      tmp->killed= Session::KILL_CONNECTION;
+      tmp->scheduler->killSession(tmp);
+      DRIZZLE_CONNECTION_DONE(tmp->thread_id);
+      tmp->lockOnSys();
+    }
   }
-  LOCK_thread_count.unlock(); // For unlink from list
 
   if (connection_count)
     sleep(2);                                   // Give threads time to die
@@ -457,16 +457,14 @@
   */
   for (;;)
   {
-    LOCK_thread_count.lock(); // For unlink from list
+    boost::mutex::scoped_lock scoped(LOCK_thread_count);
     if (getSessionList().empty())
     {
-      LOCK_thread_count.unlock();
       break;
     }
     tmp= getSessionList().front();
     /* Close before unlock, avoiding crash. See LP bug#436685 */
     tmp->client->close();
-    LOCK_thread_count.unlock();
   }
 }
 
@@ -626,7 +624,7 @@
 
   session->cleanup();
 
-  LOCK_thread_count.lock();
+  boost::mutex::scoped_lock scoped(LOCK_thread_count);
   session->lockForDelete();
 
   getSessionList().erase(remove(getSessionList().begin(),
@@ -638,7 +636,6 @@
   }
 
   delete session;
-  LOCK_thread_count.unlock();
 }
 
 

=== modified file 'drizzled/error.cc'
--- drizzled/error.cc	2010-10-06 18:22:02 +0000
+++ drizzled/error.cc	2010-10-14 18:58:48 +0000
@@ -208,9 +208,9 @@
   add(ER_YES, N_("YES"));
   add(ER_CANT_CREATE_FILE, N_("Can't create file '%-.200s' (errno: %d)"));
   add(ER_CANT_CREATE_TABLE, N_("Can't create table '%-.200s' (errno: %d)"));
-  add(ER_CANT_CREATE_DB, N_("Can't create database '%-.192s' (errno: %d)"));
-  add(ER_DB_CREATE_EXISTS, N_("Can't create database '%-.192s'; database exists"));
-  add(ER_DB_DROP_EXISTS, N_("Can't drop database '%-.192s'; database doesn't exist"));
+  add(ER_CANT_CREATE_DB, N_("Can't create schema '%-.192s' (errno: %d)"));
+  add(ER_DB_CREATE_EXISTS, N_("Can't create schema '%-.192s'; schema exists"));
+  add(ER_DB_DROP_EXISTS, N_("Can't drop schema '%-.192s'; schema doesn't exist"));
   add(ER_CANT_DELETE_FILE, N_("Error on delete of '%-.192s' (errno: %d)"));
   add(ER_CANT_GET_STAT, N_("Can't get status of '%-.200s' (errno: %d)"));
   add(ER_CANT_LOCK, N_("Can't lock file (errno: %d)"));
@@ -240,12 +240,12 @@
   add(ER_OUT_OF_RESOURCES, N_("Out of memory; check if drizzled or some other process uses all available memory; if not, you may have to use 'ulimit' to allow drizzled to use more memory or you can add more swap space"));
   add(ER_BAD_HOST_ERROR, N_("Can't get hostname for your address"));
   add(ER_HANDSHAKE_ERROR, N_("Bad handshake"));
-  add(ER_DBACCESS_DENIED_ERROR, N_("Access denied for user '%-.48s'@'%-.64s' to database '%-.192s'"));
+  add(ER_DBACCESS_DENIED_ERROR, N_("Access denied for user '%-.48s'@'%-.64s' to schema '%-.192s'"));
   add(ER_ACCESS_DENIED_ERROR, N_("Access denied for user '%-.48s'@'%-.64s' (using password: %s)"));
-  add(ER_NO_DB_ERROR, N_("No database selected"));
+  add(ER_NO_DB_ERROR, N_("No schema selected"));
   add(ER_UNKNOWN_COM_ERROR, N_("Unknown command"));
   add(ER_BAD_NULL_ERROR, N_("Column '%-.192s' cannot be null"));
-  add(ER_BAD_DB_ERROR, N_("Unknown database '%-.192s'"));
+  add(ER_BAD_DB_ERROR, N_("Unknown schema '%-.192s'"));
   add(ER_TABLE_EXISTS_ERROR, N_("Table '%-.192s' already exists"));
   add(ER_BAD_TABLE_ERROR, N_("Unknown table '%-.100s'"));
   add(ER_NON_UNIQ_ERROR, N_("Column '%-.192s' in %-.192s is ambiguous"));
@@ -280,7 +280,7 @@
   add(ER_NO_SUCH_INDEX, N_("Table '%-.192s' has no index like the one used in CREATE INDEX; recreate the table"));
   add(ER_WRONG_FIELD_TERMINATORS, N_("Field separator argument '%-.32s' with length '%d' is not what is expected; check the manual"));
   add(ER_BLOBS_AND_NO_TERMINATED, N_("You can't use fixed rowlength with BLOBs; please use 'fields terminated by'"));
-  add(ER_TEXTFILE_NOT_READABLE, N_("The file '%-.128s' must be in the database directory or be readable by all"));
+  add(ER_TEXTFILE_NOT_READABLE, N_("The file '%-.128s' must be in the schema directory or be readable by all"));
   add(ER_FILE_EXISTS_ERROR, N_("File '%-.200s' already exists"));
   add(ER_LOAD_INFO, N_("Records: %ld  Deleted: %ld  Skipped: %ld  Warnings: %ld"));
   add(ER_WRONG_SUB_KEY, N_("Incorrect prefix key; the used key part isn't a string, the used length is longer than the key part, or the storage engine doesn't support unique prefix keys"));
@@ -292,7 +292,7 @@
   add(ER_KILL_DENIED_ERROR, N_("You are not owner of thread %lu"));
   add(ER_NO_TABLES_USED, N_("No tables used"));
   add(ER_BLOB_CANT_HAVE_DEFAULT, N_("BLOB/TEXT column '%-.192s' can't have a default value"));
-  add(ER_WRONG_DB_NAME, N_("Incorrect database name '%-.100s'"));
+  add(ER_WRONG_DB_NAME, N_("Incorrect schema name '%-.100s'"));
   add(ER_WRONG_TABLE_NAME, N_("Incorrect table name '%-.100s'"));
   add(ER_TOO_BIG_SELECT, N_("The SELECT would examine more than MAX_JOIN_SIZE rows; check your WHERE and use SET SQL_BIG_SELECTS=1 or SET MAX_JOIN_SIZE=# if the SELECT is okay"));
   add(ER_UNKNOWN_ERROR, N_("Unknown error"));

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2010-10-10 19:32:58 +0000
+++ drizzled/session.cc	2010-10-14 07:05:23 +0000
@@ -552,9 +552,10 @@
   current_global_counters.connections++;
   thread_id= variables.pseudo_thread_id= global_thread_id++;
 
-  LOCK_thread_count.lock();
-  getSessionList().push_back(this);
-  LOCK_thread_count.unlock();
+  {
+    boost::mutex::scoped_lock scoped(LOCK_thread_count);
+    getSessionList().push_back(this);
+  }
 
   if (unlikely(plugin::EventObserver::connectSession(*this)))
   {
@@ -1408,21 +1409,21 @@
       switch (val_item->result_type())
       {
       case REAL_RESULT:
-	op= &select_max_min_finder_subselect::cmp_real;
-	break;
+        op= &select_max_min_finder_subselect::cmp_real;
+        break;
       case INT_RESULT:
-	op= &select_max_min_finder_subselect::cmp_int;
-	break;
+        op= &select_max_min_finder_subselect::cmp_int;
+        break;
       case STRING_RESULT:
-	op= &select_max_min_finder_subselect::cmp_str;
-	break;
+        op= &select_max_min_finder_subselect::cmp_str;
+        break;
       case DECIMAL_RESULT:
         op= &select_max_min_finder_subselect::cmp_decimal;
         break;
       case ROW_RESULT:
         // This case should never be choosen
-	assert(0);
-	op= 0;
+        assert(0);
+        op= 0;
       }
     }
     cache->store(val_item);

=== modified file 'drizzled/session_list.h'
--- drizzled/session_list.h	2010-03-04 16:54:08 +0000
+++ drizzled/session_list.h	2010-10-14 07:05:23 +0000
@@ -20,13 +20,14 @@
 #ifndef DRIZZLED_SESSION_LIST_H
 #define DRIZZLED_SESSION_LIST_H
 
-#include <vector>
+#include <list>
 
 namespace drizzled
 {
 
 class Session;
-typedef std::vector<Session *> SessionList;
+typedef Session* SessionPtr;
+typedef std::list<SessionPtr> SessionList;
 SessionList &getSessionList();
 
 }

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2010-10-15 00:59:36 +0000
+++ drizzled/sql_parse.cc	2010-10-15 03:36:56 +0000
@@ -1438,18 +1438,20 @@
 {
   Session *tmp= NULL;
   uint32_t error= ER_NO_SUCH_THREAD;
-  LOCK_thread_count.lock(); // For unlink from list
   
-  for (SessionList::iterator it= getSessionList().begin(); it != getSessionList().end(); ++it )
   {
-    if ((*it)->thread_id == id)
+    boost::mutex::scoped_lock scoped(LOCK_thread_count);
+    for (SessionList::iterator it= getSessionList().begin(); it != getSessionList().end(); ++it )
     {
-      tmp= *it;
-      tmp->lockForDelete();
-      break;
+      if ((*it)->thread_id == id)
+      {
+        tmp= *it;
+        tmp->lockForDelete();
+        break;
+      }
     }
   }
-  LOCK_thread_count.unlock();
+
   if (tmp)
   {
 

=== modified file 'drizzled/status_helper.cc'
--- drizzled/status_helper.cc	2010-10-04 13:15:05 +0000
+++ drizzled/status_helper.cc	2010-10-14 18:58:48 +0000
@@ -156,6 +156,7 @@
   {"Select_range",              (char*) offsetof(system_status_var, select_range_count), SHOW_LONGLONG_STATUS},
   {"Select_range_check",        (char*) offsetof(system_status_var, select_range_check_count), SHOW_LONGLONG_STATUS},
   {"Select_scan",               (char*) offsetof(system_status_var, select_scan_count), SHOW_LONGLONG_STATUS},
+  {"Sessions_connected",         (char*) &show_connection_count_cont_new,  SHOW_FUNC},
   {"Slow_queries",              (char*) offsetof(system_status_var, long_query_count), SHOW_LONGLONG_STATUS},
   {"Sort_merge_passes",         (char*) offsetof(system_status_var, filesort_merge_passes), SHOW_LONGLONG_STATUS},
   {"Sort_range",                (char*) offsetof(system_status_var, filesort_range_count), SHOW_LONGLONG_STATUS},
@@ -163,7 +164,6 @@
   {"Sort_scan",                 (char*) offsetof(system_status_var, filesort_scan_count), SHOW_LONGLONG_STATUS},
   {"Table_locks_immediate",     (char*) &current_global_counters.locks_immediate,        SHOW_LONGLONG},
   {"Table_locks_waited",        (char*) &current_global_counters.locks_waited,           SHOW_LONGLONG},
-  {"Threads_connected",         (char*) &show_connection_count_cont_new,  SHOW_FUNC},
   {"Uptime",                    (char*) &show_starttime_cont_new,         SHOW_FUNC},
   {"Uptime_since_flush_status", (char*) &show_flushstatustime_cont_new,   SHOW_FUNC},
   {NULL, NULL, SHOW_LONGLONG}

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2010-10-12 02:56:36 +0000
+++ drizzled/table.cc	2010-10-15 03:36:56 +0000
@@ -1940,8 +1940,7 @@
   query_id(0),
   quick_condition_rows(0),
   timestamp_field_type(TIMESTAMP_NO_AUTO_SET),
-  map(0),
-  is_placeholder_created(0)
+  map(0)
 {
   record[0]= (unsigned char *) 0;
   record[1]= (unsigned char *) 0;

=== modified file 'drizzled/table.h'
--- drizzled/table.h	2010-10-11 21:57:03 +0000
+++ drizzled/table.h	2010-10-14 06:00:01 +0000
@@ -637,13 +637,10 @@
     return output;  // for multiple << operators.
   }
 
-protected:
-  bool is_placeholder_created;
-
 public:
-  bool isPlaceHolder()
+  virtual bool isPlaceHolder(void) const
   {
-    return is_placeholder_created;
+    return false;
   }
 };
 

=== modified file 'drizzled/table_placeholder.h'
--- drizzled/table_placeholder.h	2010-06-15 13:37:26 +0000
+++ drizzled/table_placeholder.h	2010-10-14 06:00:01 +0000
@@ -35,12 +35,16 @@
     Table(),
     private_share(identifier, identifier.getKey())
   {
-    is_placeholder_created= true;
     setShare(&private_share);
     in_use= session;
 
     locked_by_name= true;
   }
+
+  bool isPlaceHolder(void) const
+  {
+    return true;
+  }
 };
 
 } /* namespace drizzled */

=== modified file 'drizzled/table_share_instance.h'
--- drizzled/table_share_instance.h	2010-10-11 21:57:03 +0000
+++ drizzled/table_share_instance.h	2010-10-14 06:05:44 +0000
@@ -38,11 +38,6 @@
   {
   }
 
-  Table *getTable()
-  {
-    return this;
-  }
-
   TableShare *getMutableShare(void)
   {
     return &_share;
@@ -65,7 +60,7 @@
 
   ~TableShareInstance()
   {
-    this->free_tmp_table(this->in_use);
+    free_tmp_table(this->in_use);
   }
 };
 

=== modified file 'plugin/innobase/tests/r/innodb.result'
--- plugin/innobase/tests/r/innodb.result	2010-10-12 05:56:25 +0000
+++ plugin/innobase/tests/r/innodb.result	2010-10-15 03:36:56 +0000
@@ -825,7 +825,7 @@
 commit;
 drop database mysqltest;
 show tables from mysqltest;
-ERROR 42000: Unknown database 'mysqltest'
+ERROR 42000: Unknown schema 'mysqltest'
 set autocommit=0;
 create table t1 (a int not null) engine= innodb;
 insert into t1 values(1),(2);

=== modified file 'plugin/logging_stats/tests/r/max_session.result'
--- plugin/logging_stats/tests/r/max_session.result	2010-08-09 18:29:06 +0000
+++ plugin/logging_stats/tests/r/max_session.result	2010-10-14 18:58:48 +0000
@@ -58,6 +58,7 @@
 Select_range	#
 Select_range_check	#
 Select_scan	#
+Sessions_connected	#
 Slow_queries	#
 Sort_merge_passes	#
 Sort_range	#
@@ -65,6 +66,5 @@
 Sort_scan	#
 Table_locks_immediate	#
 Table_locks_waited	#
-Threads_connected	#
 Uptime	#
 Uptime_since_flush_status	#

=== modified file 'plugin/myisam/tests/r/mix2_myisam.result'
--- plugin/myisam/tests/r/mix2_myisam.result	2010-09-12 14:34:27 +0000
+++ plugin/myisam/tests/r/mix2_myisam.result	2010-10-14 18:58:48 +0000
@@ -681,7 +681,7 @@
 commit;
 drop database mysqltest;
 show tables from mysqltest;
-ERROR 42000: Unknown database 'mysqltest'
+ERROR 42000: Unknown schema 'mysqltest'
 set autocommit=0;
 create TEMPORARY table t1 (a int not null) engine= MyISAM;
 insert into t1 values(1),(2);

=== removed directory 'plugin/pool_of_threads'
=== removed file 'plugin/pool_of_threads/plugin.ac'
--- plugin/pool_of_threads/plugin.ac	2009-11-24 18:25:09 +0000
+++ plugin/pool_of_threads/plugin.ac	1970-01-01 00:00:00 +0000
@@ -1,5 +0,0 @@
-PANDORA_HAVE_LIBEVENT
-AS_IF([test x$ac_cv_libevent = xno],
-  AC_MSG_WARN([Couldnt find a recent libevent pool-of-threads scheduler will not be built. On Debian this can be found in libevent-dev. On RedHat its in libevent-devel.]))
-
-

=== removed file 'plugin/pool_of_threads/plugin.ini'
--- plugin/pool_of_threads/plugin.ini	2010-09-15 20:24:31 +0000
+++ plugin/pool_of_threads/plugin.ini	1970-01-01 00:00:00 +0000
@@ -1,12 +0,0 @@
-[plugin]
-title=Pool of Threads Scheduler
-description=Pool of Threads Scheduler
-sources=pool_of_threads.cc session_scheduler.cc
-headers=pool_of_threads.h session_scheduler.h
-load_by_default=no
-static=no
-cxxflags=${PROTOSKIP_WARNINGS}
-ldflags=${LTLIBEVENT}
-build_conditional="x$ac_cv_libevent" = "xyes"
-#uncomment when pool_of_threads shutdown is fixed
-testsuite=disable

=== removed file 'plugin/pool_of_threads/pool_of_threads.cc'
--- plugin/pool_of_threads/pool_of_threads.cc	2010-09-16 00:50:10 +0000
+++ plugin/pool_of_threads/pool_of_threads.cc	1970-01-01 00:00:00 +0000
@@ -1,678 +0,0 @@
-/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
- * vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
- *
- * Copyright (C) 2006 MySQL AB
- * Copyright (C) 2009 Sun Microsystems
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
- */
-
-#include "config.h"
-#include <fcntl.h>
-#include <plugin/pool_of_threads/pool_of_threads.h>
-#include "drizzled/pthread_globals.h"
-#include "drizzled/internal/my_pthread.h"
-#include <boost/program_options.hpp>
-#include <drizzled/module/option_map.h>
-
-#include <boost/thread/thread.hpp>
-#include <boost/bind.hpp>
-
-namespace po= boost::program_options;
-using namespace std;
-using namespace drizzled;
-
-/* Global's (TBR) */
-
-/**
- * Set this to true to trigger killing of all threads in the pool
- */
-static volatile bool kill_pool_threads= false;
-
-static volatile uint32_t created_threads= 0;
-
-static struct event session_add_event;
-static struct event session_kill_event;
-
-
-static int session_add_pipe[2]; /* pipe to signal add a connection to libevent*/
-static int session_kill_pipe[2]; /* pipe to signal kill a connection in libevent */
-
-
-static bool libevent_needs_immediate_processing(Session *session);
-static void libevent_connection_close(Session *session);
-void libevent_session_add(Session* session);
-bool libevent_should_close_connection(Session* session);
-void libevent_thread_proc(PoolOfThreadsScheduler *pot_scheduler);
-extern "C" {
-#if 0
-  void *libevent_thread_proc(void *arg);
-#endif
-  void libevent_io_callback(int Fd, short Operation, void *ctx);
-  void libevent_add_session_callback(int Fd, short Operation, void *ctx);
-  void libevent_kill_session_callback(int Fd, short Operation, void *ctx);
-}
-
-static uint32_t pool_size;
-
-/**
- * @brief 
- *  Create a pipe and set to non-blocking. 
- * @return 
- *  True if there is an error.
- */
-static bool init_pipe(int pipe_fds[])
-{
-  int flags;
-  return pipe(pipe_fds) < 0 ||
-          (flags= fcntl(pipe_fds[0], F_GETFL)) == -1 ||
-          fcntl(pipe_fds[0], F_SETFL, flags | O_NONBLOCK) == -1 ||
-          (flags= fcntl(pipe_fds[1], F_GETFL)) == -1 ||
-          fcntl(pipe_fds[1], F_SETFL, flags | O_NONBLOCK) == -1;
-}
-
-
-
-
-
-/**
- * @brief
- *  This is called when data is ready on the socket.
- *
- * @details
- *  This is only called by the thread that owns LOCK_event_loop.
- *
- *  We add the session that got the data to sessions_need_processing, and
- *  cause the libevent event_loop() to terminate. Then this same thread will
- *  return from event_loop and pick the session value back up for
- *  processing.
- */
-void libevent_io_callback(int, short, void *ctx)
-{
-  Session *session= reinterpret_cast<Session*>(ctx);
-  session_scheduler *sched= static_cast<session_scheduler *>(session->scheduler_arg);
-  assert(sched);
-  PoolOfThreadsScheduler *pot_scheduler= static_cast<PoolOfThreadsScheduler *>(session->scheduler);
-  pot_scheduler->doIO(sched);
-}
-
-void PoolOfThreadsScheduler::doIO(session_scheduler *sched)
-{
-  safe_mutex_assert_owner(&LOCK_event_loop);
-  sessions_waiting_for_io.erase(sched->session);
-  sessions_need_processing.push(sched->session);
-}
-/**
- * @brief
- *  This is called when we have a thread we want to be killed.
- *
- * @details
- *  This is only called by the thread that owns LOCK_event_loop.
- */
-void libevent_kill_session_callback(int Fd, short, void *ctx)
-{
-  PoolOfThreadsScheduler *pot_scheduler=
-    reinterpret_cast<PoolOfThreadsScheduler *>(ctx);
-
-  pot_scheduler->killSession(Fd);
-}
-
-void PoolOfThreadsScheduler::killSession(int Fd)
-{
-  safe_mutex_assert_owner(&LOCK_event_loop);
-  /*
-   For pending events clearing
-  */
-  char c;
-  int count= 0;
-
-  LOCK_session_kill.lock();
-  while (! sessions_to_be_killed.empty())
-  {
-
-    /*
-     Fetch a session from the queue
-    */
-    Session* session= sessions_to_be_killed.front();
-    LOCK_session_kill.unlock();
-
-    session_scheduler *sched= static_cast<session_scheduler *>(session->scheduler_arg);
-    assert(sched);
-
-    /*
-     Delete from libevent and add to the processing queue.
-    */
-    event_del(&sched->io_event);
-    /*
-     Remove from the sessions_waiting_for_io set
-    */
-    sessions_waiting_for_io.erase(session);
-    /*
-     Push into the sessions_need_processing; the kill action will be
-     performed out of the event loop
-    */
-    sessions_need_processing.push(sched->session);
-
-    LOCK_session_kill.lock();
-    /*
-     Pop until this session is already processed
-    */
-    sessions_to_be_killed.pop();
-  }
-  
-  /*
-   Clear the pending events 
-   One and only one charactor should be in the pipe
-  */
-  while (read(Fd, &c, sizeof(c)) == sizeof(c))
-  {
-    count++;
-  }
-  assert(count == 1);
-  LOCK_session_kill.unlock();
-}
-
-
-/**
- * @brief
- *  This is used to add connections to the pool. This callback is invoked
- *  from the libevent event_loop() call whenever the session_add_pipe[1]
- *  pipe has a byte written to it.
- *
- * @details
- *  This is only called by the thread that owns LOCK_event_loop.
- */
-void libevent_add_session_callback(int Fd, short, void *ctx)
-{
-  PoolOfThreadsScheduler *pot_scheduler=
-    reinterpret_cast<PoolOfThreadsScheduler *>(ctx);
-  pot_scheduler->addSession(Fd);
-}
-
-void PoolOfThreadsScheduler::addSession(int Fd)
-{
-  safe_mutex_assert_owner(&LOCK_event_loop);
-  /*
-   For pending events clearing
-  */
-  char c;
-  int count= 0;
-
-  LOCK_session_add.lock();
-  while (! sessions_need_adding.empty())
-  {
-    /*
-     Pop the first session off the queue 
-    */
-    Session* session= sessions_need_adding.front();
-    LOCK_session_add.unlock();
-
-    session_scheduler *sched= static_cast<session_scheduler *>(session->scheduler_arg);
-    assert(sched);
-
-
-    if (!sched->logged_in || libevent_should_close_connection(session))
-    {
-      /*
-       Add session to sessions_need_processing queue. If it needs closing
-       we'll close it outside of event_loop().
-      */
-      sessions_need_processing.push(sched->session);
-    }
-    else
-    {
-      /* Add to libevent */
-      if (event_add(&sched->io_event, NULL))
-      {
-        errmsg_printf(ERRMSG_LVL_ERROR, _("event_add error in libevent_add_session_callback\n"));
-        libevent_connection_close(session);
-      }
-      else
-      {
-        sessions_waiting_for_io.insert(sched->session);
-      }
-    }
-
-    LOCK_session_add.lock();
-    /*
-     Pop until this session is already processed
-    */
-    sessions_need_adding.pop();
-  }
-
-  /*
-   Clear the pending events 
-   One and only one charactor should be in the pipe
-  */
-  while (read(Fd, &c, sizeof(c)) == sizeof(c))
-  {
-    count++;
-  }
-  assert(count == 1);
-  LOCK_session_add.unlock();
-}
-
-/**
- * @brief 
- *  Close and delete a connection.
- */
-static void libevent_connection_close(Session *session)
-{
-  session_scheduler *sched= (session_scheduler *)session->scheduler_arg;
-  assert(sched);
-  session->killed= Session::KILL_CONNECTION;    /* Avoid error messages */
-
-  if (session->client->getFileDescriptor() >= 0) /* not already closed */
-  {
-    session->disconnect(0, true);
-  }
-  sched->thread_detach();
-  
-  delete sched;
-  session->scheduler_arg= NULL;
-
-  Session::unlink(session);   /* locks LOCK_thread_count and deletes session */
-
-  return;
-}
-
-
-/**
- * @brief 
- *  Checks if a session should be closed.
- *  
- * @retval true this session should be closed.  
- * @retval false not to be closed.
- */
-bool libevent_should_close_connection(Session* session)
-{
-  return session->client->haveError() ||
-         session->killed == Session::KILL_CONNECTION;
-}
-
-
-/**
- * @brief
- *  libevent_thread_proc is the outer loop of each thread in the thread pool.
- *  These procs only return/terminate on shutdown (kill_pool_threads ==
- *  true).
- */
-void libevent_thread_proc(PoolOfThreadsScheduler *pot_scheduler)
-{
-  if (internal::my_thread_init())
-  {
-    internal::my_thread_global_end();
-    errmsg_printf(ERRMSG_LVL_ERROR, _("libevent_thread_proc: internal::my_thread_init() failed\n"));
-    exit(1);
-  }
-
-  (void)pot_scheduler->mainLoop();
-}
-
-void *PoolOfThreadsScheduler::mainLoop()
-{
-  /*
-   Signal libevent_init() when all threads has been created and are ready
-   to receive events.
-  */
-  (void) LOCK_thread_count.lock();
-  created_threads++;
-  if (created_threads == pool_size)
-    COND_thread_count.notify_one();
-
-  (void) LOCK_thread_count.unlock();
-
-  for (;;)
-  {
-    Session *session= NULL;
-    LOCK_event_loop.lock();
-
-    /* get session(s) to process */
-    while (sessions_need_processing.empty())
-    {
-      if (kill_pool_threads)
-      {
-        /* the flag that we should die has been set */
-        LOCK_event_loop.unlock();
-        goto thread_exit;
-      }
-      event_loop(EVLOOP_ONCE);
-    }
-
-    /* pop the first session off the queue */
-    session= sessions_need_processing.front();
-    sessions_need_processing.pop();
-    session_scheduler *sched= (session_scheduler *)session->scheduler_arg;
-
-    LOCK_event_loop.lock();
-
-    /* now we process the connection (session) */
-
-    /* set up the session<->thread links. */
-    session->thread_stack= (char*) &session;
-
-    if (sched->thread_attach())
-    {
-      libevent_connection_close(session);
-      continue;
-    }
-
-    /* is the connection logged in yet? */
-    if (!sched->logged_in)
-    {
-      if (session->authenticate())
-      {
-        /* Failed to log in */
-        libevent_connection_close(session);
-        continue;
-      }
-      else
-      {
-        /* login successful */
-        sched->logged_in= true;
-        session->prepareForQueries();
-        if (!libevent_needs_immediate_processing(session))
-          continue; /* New connection is now waiting for data in libevent*/
-      }
-    }
-
-    do
-    {
-      /* Process a query */
-      if (! session->executeStatement())
-      {
-        libevent_connection_close(session);
-        break;
-      }
-    } while (libevent_needs_immediate_processing(session));
-
-    if (kill_pool_threads) /* the flag that we should die has been set */
-      goto thread_exit;
-  }
-
-thread_exit:
-  (void) LOCK_thread_count.lock();
-  created_threads--;
-  COND_thread_count.notify_all();
-  (void) LOCK_thread_count.unlock();
-  internal::my_thread_end();
-  pthread_exit(0);
-
-  return NULL;                               /* purify: deadcode */
-}
-
-
-/**
- * @brief
- *  Checks if a session needs immediate processing
- *
- * @retval true the session needs immediate processing 
- * @retval false if not, and is detached from the thread waiting for another
- * adding. The naming of the function is misleading in this case; it
- * actually does more than just checking if immediate processing is needed.
- */
-static bool libevent_needs_immediate_processing(Session *session)
-{
-  session_scheduler *sched= (session_scheduler *)session->scheduler_arg;
-
-  if (libevent_should_close_connection(session))
-  {
-    libevent_connection_close(session);
-    return false;
-  }
-  /*
-   If more data in the socket buffer, return true to process another command.
-  
-   Note: we cannot add for event processing because the whole request
-   might already be buffered and we wouldn't receive an event. This is
-   indeed the root of the reason of low performace. Need to be changed
-   when nonblocking Protocol is finished.
-  */
-  if (session->client->haveMoreData())
-    return true;
-
-  sched->thread_detach();
-  libevent_session_add(session);
-
-  return false;
-}
-
-
-/**
- * @brief 
- *  Adds a Session to queued for libevent processing.
- * 
- * @details
- *  This call does not actually register the event with libevent.
- *  Instead, it places the Session onto a queue and signals libevent by writing
- *  a byte into session_add_pipe, which will cause our libevent_add_session_callback to
- *  be invoked which will find the Session on the queue and add it to libevent.
- */
-void libevent_session_add(Session* session)
-{
-  session_scheduler *sched= (session_scheduler *)session->scheduler_arg;
-  assert(sched);
-  PoolOfThreadsScheduler *pot_scheduler=
-    static_cast<PoolOfThreadsScheduler *>(session->scheduler);
-  pot_scheduler->sessionAddToQueue(sched);
-}
-
-void PoolOfThreadsScheduler::sessionAddToQueue(session_scheduler *sched)
-{
-  char c= 0;
-  boost::mutex::scoped_lock scopedLock(LOCK_session_add);
-  if (sessions_need_adding.empty())
-  {
-    /* notify libevent */
-    size_t written= write(session_add_pipe[1], &c, sizeof(c));
-    assert(written == sizeof(c));
-  }
-  /* queue for libevent */
-  sessions_need_adding.push(sched->session);
-}
-
-
-PoolOfThreadsScheduler::PoolOfThreadsScheduler(const char *name_arg)
-  : Scheduler(name_arg), sessions_need_adding(), sessions_to_be_killed(),
-    sessions_need_processing(), sessions_waiting_for_io()
-{
-  /* Setup attribute parameter for session threads. */
-  (void) pthread_attr_init(&attr);
-  (void) pthread_attr_setdetachstate(&attr, PTHREAD_CREATE_DETACHED);
-  pthread_attr_setscope(&attr, PTHREAD_SCOPE_SYSTEM);
-}
-
-
-PoolOfThreadsScheduler::~PoolOfThreadsScheduler()
-{
-  (void) LOCK_thread_count.lock();
-
-  kill_pool_threads= true;
-  while (created_threads)
-  {
-    /*
-     * Wake up the event loop
-     */
-    char c= 0;
-    size_t written= write(session_add_pipe[1], &c, sizeof(c));
-    assert(written == sizeof(c));
-
-    pthread_cond_wait(COND_thread_count.native_handle(), LOCK_thread_count.native_handle());
-  }
-  (void) LOCK_thread_count.unlock();
-
-  event_del(&session_add_event);
-  close(session_add_pipe[0]);
-  close(session_add_pipe[1]);
-  event_del(&session_kill_event);
-  close(session_kill_pipe[0]);
-  close(session_kill_pipe[1]);
-
-  (void) pthread_attr_destroy(&attr);
-}
-
-
-bool PoolOfThreadsScheduler::addSession(Session *session)
-{
-  assert(session->scheduler_arg == NULL);
-  session_scheduler *sched= new session_scheduler(session);
-
-  if (sched == NULL)
-    return true;
-
-  session->scheduler_arg= (void *)sched;
-
-  libevent_session_add(session);
-
-  return false;
-}
-
-
-void PoolOfThreadsScheduler::killSession(Session *session)
-{
-  char c= 0;
-
-  boost::mutex::scoped_lock scopedLock(LOCK_session_kill);
-
-  if (sessions_to_be_killed.empty())
-  {
-    /* 
-      Notify libevent with the killing event if this's the first killing
-      notification of the batch
-    */
-    size_t written= write(session_kill_pipe[1], &c, sizeof(c));
-    assert(written == sizeof(c));
-  }
-
-  /*
-    Push into the sessions_to_be_killed queue
-  */
-  sessions_to_be_killed.push(session);
-}
-
-
-bool PoolOfThreadsScheduler::libevent_init(void)
-{
-  event_init();
-
-
-  /* Set up the pipe used to add new sessions to the event pool */
-  if (init_pipe(session_add_pipe))
-  {
-    errmsg_printf(ERRMSG_LVL_ERROR,
-                  _("init_pipe(session_add_pipe) error in libevent_init\n"));
-    return true;
-  }
-  /* Set up the pipe used to kill sessions in the event queue */
-  if (init_pipe(session_kill_pipe))
-  {
-    errmsg_printf(ERRMSG_LVL_ERROR,
-                  _("init_pipe(session_kill_pipe) error in libevent_init\n"));
-    close(session_add_pipe[0]);
-    close(session_add_pipe[1]);
-    return true;
-  }
-  event_set(&session_add_event, session_add_pipe[0], EV_READ|EV_PERSIST,
-            libevent_add_session_callback, this);
-  event_set(&session_kill_event, session_kill_pipe[0], EV_READ|EV_PERSIST,
-            libevent_kill_session_callback, this);
-
-  if (event_add(&session_add_event, NULL) || event_add(&session_kill_event, NULL))
-  {
-    errmsg_printf(ERRMSG_LVL_ERROR, _("session_add_event event_add error in libevent_init\n"));
-    return true;
-
-  }
-  /* Set up the thread pool */
-  boost::mutex::scoped_lock scopedLock(LOCK_thread_count);
-
-  for (uint32_t x= 0; x < pool_size; x++)
-  {
-    if (not new boost::thread(boost::bind(libevent_thread_proc, this)))
-    {
-      errmsg_printf(ERRMSG_LVL_ERROR, _("Can't create completion port thread (error %d)"), 1);
-      return true;
-    }
-  }
-
-  /* Wait until all threads are created */
-  while (created_threads != pool_size)
-  {
-    COND_thread_count.wait(scopedLock);
-  }
-
-  return false;
-}
-
-
-/**
- * @brief
- *  Called to initialize the pool of threads scheduler plugin
- * 
- * @param[in] registry holding the record of the plugins
- */
-static int init(drizzled::module::Context &context)
-{
-  const module::option_map &vm= context.getOptions();
- 
-  if (vm.count("size"))
-  {
-    if (pool_size > 1024 || pool_size < 1)
-    {
-      errmsg_printf(ERRMSG_LVL_ERROR, _("Invalid value for size\n"));
-      exit(-1);
-    }
-  }
-
-  assert(pool_size != 0);
-
-  context.add(new PoolOfThreadsScheduler("pool_of_threads"));
-
-  return 0;
-}
-
-/*
- The defaults here were picked based on what I see (aka Brian). They should
- be vetted across a larger audience.
-*/
-static DRIZZLE_SYSVAR_UINT(size, pool_size,
-                           PLUGIN_VAR_RQCMDARG,
-                           N_("Size of Pool."),
-                           NULL, NULL, 8, 1, 1024, 0);
-
-static void init_options(drizzled::module::option_context &context)
-{
-  context("size",
-          po::value<uint32_t>(&pool_size)->default_value(8),
-          N_("Size of Pool."));
-}
-
-static drizzle_sys_var* sys_variables[]= {
-  DRIZZLE_SYSVAR(size),
-  NULL,
-};
-
-DRIZZLE_DECLARE_PLUGIN
-{
-  DRIZZLE_VERSION_ID,
-  "pool_of_threads",
-  "0.1",
-  "Brian Aker",
-  "Pool of Threads Scheduler",
-  PLUGIN_LICENSE_GPL,
-  init, /* Plugin Init */
-  sys_variables,   /* system variables */
-  init_options    /* config options */
-}
-DRIZZLE_DECLARE_PLUGIN_END;

=== removed file 'plugin/pool_of_threads/pool_of_threads.h'
--- plugin/pool_of_threads/pool_of_threads.h	2010-09-15 20:24:31 +0000
+++ plugin/pool_of_threads/pool_of_threads.h	1970-01-01 00:00:00 +0000
@@ -1,114 +0,0 @@
-/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
- * vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
- *
- * Copyright (C) 2009 Sun Microsystems
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
- */
-
-#ifndef PLUGIN_POOL_OF_THREADS_POOL_OF_THREADS_H
-#define PLUGIN_POOL_OF_THREADS_POOL_OF_THREADS_H
-
-#include <drizzled/gettext.h>
-#include <drizzled/error.h>
-#include <drizzled/plugin/scheduler.h>
-#include <drizzled/sql_parse.h>
-#include <drizzled/session.h>
-#include <drizzled/plugin/client.h>
-#include "session_scheduler.h"
-#include <string>
-#include <queue>
-#include <boost/unordered_set.hpp>
-#include <event.h>
-
-
-/**
- * @brief
- *  Derived class for pool of threads scheduler.
- */
-class PoolOfThreadsScheduler: public drizzled::plugin::Scheduler
-{
-private:
-  pthread_attr_t attr;
-
-  boost::mutex LOCK_session_add;    /* protects sessions_need_adding */
-  boost::mutex LOCK_session_kill;    /* protects sessions_to_be_killed */
-  /**
-   * LOCK_event_loop protects the non-thread safe libevent calls (event_add
-   * and event_del) and sessions_need_processing and sessions_waiting_for_io.
-   */
-  boost::mutex LOCK_event_loop;
-
-  std::queue<drizzled::Session *> sessions_need_adding; /* queue of sessions to add to libevent queue */
-  std::queue<drizzled::Session *> sessions_to_be_killed; /* queue of sessions to be killed */
-  std::queue<drizzled::Session *> sessions_need_processing; /* queue of sessions that needs some processing */
-  /**
-   * Collection of sessions with added events
-   *
-   * This should really be a collection of unordered Sessions. No one is more
-   * promising to encounter an io event earlier than another; so no order
-   * indeed!
-   */
-  boost::unordered_set<drizzled::Session *> sessions_waiting_for_io;
-
-public:
-  PoolOfThreadsScheduler(const char *name_arg);
-  ~PoolOfThreadsScheduler();
-
-  /**
-   * @brief
-   *  Notify the thread pool about a new connection
-   *
-   * @param[in] the newly connected session
-   *
-   * @return 
-   *  True if there is an error.
-   */
-  bool addSession(drizzled::Session *session);
-  
-  
-  /**
-   * @brief
-   *  Signal a waiting connection it's time to die.
-   *
-   * @details 
-   *  This function will signal libevent the Session should be killed.
-   *
-   * @param[in]  session The connection to kill
-   */
-  void killSession(drizzled::Session *session);
-
-  /**
-   * @brief
-   *  Create all threads for the thread pool
-   *
-   * @details
-   *  After threads are created we wait until all threads has signaled that
-   *  they have started before we return
-   *
-   * @retval 0 Ok
-   * @retval 1 We got an error creating the thread pool. In this case we will abort all created threads.
-   */
-  bool libevent_init(void);
-
-  void doIO(session_scheduler *sched);
-  void killSession(int Fd);
-  void addSession(int Fd);
-  void *mainLoop();
-  void sessionAddToQueue(session_scheduler *sched);
-
-
-};
-
-#endif /* PLUGIN_POOL_OF_THREADS_POOL_OF_THREADS_H */

=== removed file 'plugin/pool_of_threads/session_scheduler.cc'
--- plugin/pool_of_threads/session_scheduler.cc	2010-10-02 21:15:42 +0000
+++ plugin/pool_of_threads/session_scheduler.cc	1970-01-01 00:00:00 +0000
@@ -1,79 +0,0 @@
-/* Copyright (C) 2009 Sun Microsystems
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
-
-/*
-  session_scheduler keeps the link between Session and events.
-  It's embedded in the Session class.
-*/
-
-#include "config.h"
-#include <drizzled/session.h>
-#include <drizzled/gettext.h>
-#include <drizzled/errmsg_print.h>
-#include <drizzled/plugin/client.h>
-#include <event.h>
-#include "session_scheduler.h"
-#include "drizzled/internal/my_sys.h"
-#include "drizzled/internal/thread_var.h"
-
-/* Prototype */
-extern "C"
-void libevent_io_callback(int Fd, short Operation, void *ctx);
-bool libevent_should_close_connection(drizzled::Session* session);
-void libevent_session_add(drizzled::Session* session);
-
-session_scheduler::session_scheduler(drizzled::Session *parent_session)
-  : logged_in(false), thread_attached(false)
-{
-  memset(&io_event, 0, sizeof(struct event));
-
-  event_set(&io_event, parent_session->client->getFileDescriptor(), EV_READ,
-            libevent_io_callback, (void*)parent_session);
-
-  session= parent_session;
-}
-
-/*
-  Attach/associate the connection with the OS thread, for command processing.
-*/
-
-bool session_scheduler::thread_attach()
-{
-  assert(!thread_attached);
-  if (libevent_should_close_connection(session) ||
-      session->initGlobals())
-  {
-    return true;
-  }
-  errno= 0;
-  session->getThreadVar()->abort= 0;
-  thread_attached= true;
-
-  return false;
-}
-
-
-/*
-  Detach/disassociate the connection with the OS thread.
-*/
-
-void session_scheduler::thread_detach()
-{
-  if (thread_attached)
-  {
-    session->resetThreadVar();
-    thread_attached= false;
-  }
-}

=== removed file 'plugin/pool_of_threads/session_scheduler.h'
--- plugin/pool_of_threads/session_scheduler.h	2010-10-02 21:15:42 +0000
+++ plugin/pool_of_threads/session_scheduler.h	1970-01-01 00:00:00 +0000
@@ -1,39 +0,0 @@
-/* Copyright (C) 2009 Sun Microsystems
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
-
-#ifndef PLUGIN_POOL_OF_THREADS_SESSION_SCHEDULER_H
-#define PLUGIN_POOL_OF_THREADS_SESSION_SCHEDULER_H
-
-#include <event.h>
-
-namespace drizzled
-{
-class Session;
-}
-
-class session_scheduler
-{
-public:
-  bool logged_in;
-  struct event io_event;
-  drizzled::Session *session;
-  bool thread_attached;  /* Indicates if Session is attached to the OS thread */
-
-  session_scheduler(drizzled::Session *);
-  bool thread_attach();
-  void thread_detach();
-};
-
-#endif /* PLUGIN_POOL_OF_THREADS_SESSION_SCHEDULER_H */

=== removed directory 'plugin/pool_of_threads/tests'
=== removed directory 'plugin/pool_of_threads/tests/r'
=== removed file 'plugin/pool_of_threads/tests/r/pool_of_threads.result'
--- plugin/pool_of_threads/tests/r/pool_of_threads.result	2009-11-12 00:44:38 +0000
+++ plugin/pool_of_threads/tests/r/pool_of_threads.result	1970-01-01 00:00:00 +0000
@@ -1,2136 +0,0 @@
-drop table if exists t1,t2,t3,t4;
-CREATE TABLE t1 (
-Period int DEFAULT '0000' NOT NULL,
-Varor_period int DEFAULT '0' NOT NULL
-);
-INSERT INTO t1 VALUES (9410,9412);
-select period from t1;
-period
-9410
-select * from t1;
-Period	Varor_period
-9410	9412
-select t1.* from t1;
-Period	Varor_period
-9410	9412
-CREATE TABLE t2 (
-auto int not null auto_increment,
-fld1 int DEFAULT '000000' NOT NULL,
-companynr int DEFAULT '00' NOT NULL,
-fld3 char(30) DEFAULT '' NOT NULL,
-fld4 char(35) DEFAULT '' NOT NULL,
-fld5 char(35) DEFAULT '' NOT NULL,
-fld6 char(4) DEFAULT '' NOT NULL,
-UNIQUE fld1 (fld1),
-KEY fld3 (fld3),
-PRIMARY KEY (auto)
-);
-select t2.fld3 from t2 where companynr = 58 and fld3 like "%imaginable%";
-fld3
-imaginable
-select fld3 from t2 where fld3 like "%cultivation" ;
-fld3
-cultivation
-select t2.fld3,companynr from t2 where companynr = 57+1 order by fld3;
-fld3	companynr
-concoct	58
-druggists	58
-engrossing	58
-Eurydice	58
-exclaimers	58
-ferociousness	58
-hopelessness	58
-Huey	58
-imaginable	58
-judges	58
-merging	58
-ostrich	58
-peering	58
-Phelps	58
-presumes	58
-Ruth	58
-sentences	58
-Shylock	58
-straggled	58
-synergy	58
-thanking	58
-tying	58
-unlocks	58
-select fld3,companynr from t2 where companynr = 58 order by fld3;
-fld3	companynr
-concoct	58
-druggists	58
-engrossing	58
-Eurydice	58
-exclaimers	58
-ferociousness	58
-hopelessness	58
-Huey	58
-imaginable	58
-judges	58
-merging	58
-ostrich	58
-peering	58
-Phelps	58
-presumes	58
-Ruth	58
-sentences	58
-Shylock	58
-straggled	58
-synergy	58
-thanking	58
-tying	58
-unlocks	58
-select fld3 from t2 order by fld3 desc limit 10;
-fld3
-youthfulness
-yelped
-Wotan
-workers
-Witt
-witchcraft
-Winsett
-Willy
-willed
-wildcats
-select fld3 from t2 order by fld3 desc limit 5;
-fld3
-youthfulness
-yelped
-Wotan
-workers
-Witt
-select fld3 from t2 order by fld3 desc limit 5,5;
-fld3
-witchcraft
-Winsett
-Willy
-willed
-wildcats
-select t2.fld3 from t2 where fld3 = 'honeysuckle';
-fld3
-honeysuckle
-select t2.fld3 from t2 where fld3 LIKE 'honeysuckl_';
-fld3
-honeysuckle
-select t2.fld3 from t2 where fld3 LIKE 'hon_ysuckl_';
-fld3
-honeysuckle
-select t2.fld3 from t2 where fld3 LIKE 'honeysuckle%';
-fld3
-honeysuckle
-select t2.fld3 from t2 where fld3 LIKE 'h%le';
-fld3
-honeysuckle
-select t2.fld3 from t2 where fld3 LIKE 'honeysuckle_';
-fld3
-select t2.fld3 from t2 where fld3 LIKE 'don_t_find_me_please%';
-fld3
-explain select t2.fld3 from t2 where fld3 = 'honeysuckle';
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	ref	fld3	fld3	122	const	#	Using where; Using index
-explain select fld3 from t2 ignore index (fld3) where fld3 = 'honeysuckle';
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	Using where
-explain select fld3 from t2 use index (fld1) where fld3 = 'honeysuckle';
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	Using where
-explain select fld3 from t2 use index (fld3) where fld3 = 'honeysuckle';
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	ref	fld3	fld3	122	const	#	Using where; Using index
-explain select fld3 from t2 use index (fld1,fld3) where fld3 = 'honeysuckle';
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	ref	fld3	fld3	122	const	#	Using where; Using index
-explain select fld3 from t2 ignore index (fld3,not_used);
-ERROR 42000: Key 'not_used' doesn't exist in table 't2'
-explain select fld3 from t2 use index (not_used);
-ERROR 42000: Key 'not_used' doesn't exist in table 't2'
-select t2.fld3 from t2 where fld3 >= 'honeysuckle' and fld3 <= 'honoring' order by fld3;
-fld3
-honeysuckle
-honoring
-explain select t2.fld3 from t2 where fld3 >= 'honeysuckle' and fld3 <= 'honoring' order by fld3;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	range	fld3	fld3	122	NULL	#	Using where; Using index
-select fld1,fld3 from t2 where fld3="Colombo" or fld3 = "nondecreasing" order by fld3;
-fld1	fld3
-148504	Colombo
-68305	Colombo
-0	nondecreasing
-select fld1,fld3 from t2 where companynr = 37 and fld3 = 'appendixes';
-fld1	fld3
-232605	appendixes
-1232605	appendixes
-1232606	appendixes
-1232607	appendixes
-1232608	appendixes
-1232609	appendixes
-select fld1 from t2 where fld1=250501 or fld1="250502";
-fld1
-250501
-250502
-explain select fld1 from t2 where fld1=250501 or fld1="250502";
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	range	fld1	fld1	4	NULL	#	Using where; Using index
-select fld1 from t2 where fld1=250501 or fld1=250502 or fld1 >= 250505 and fld1 <= 250601 or fld1 between 250501 and 250502;
-fld1
-250501
-250502
-250505
-250601
-explain select fld1 from t2 where fld1=250501 or fld1=250502 or fld1 >= 250505 and fld1 <= 250601 or fld1 between 250501 and 250502;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	range	fld1	fld1	4	NULL	#	Using where; Using index
-select fld1,fld3 from t2 where companynr = 37 and fld3 like 'f%';
-fld1	fld3
-218401	faithful
-18007	fanatic
-228311	fated
-18017	featherweight
-218022	feed
-88303	feminine
-58004	Fenton
-38017	fetched
-18054	fetters
-208101	fiftieth
-238007	filial
-13606	fingerings
-218008	finishers
-38205	firearm
-188505	fitting
-202301	Fitzpatrick
-238008	fixedly
-12001	flanking
-18103	flint
-18104	flopping
-188007	flurried
-13602	foldout
-226205	foothill
-232102	forgivably
-228306	forthcoming
-186002	freakish
-208113	freest
-231315	freezes
-36002	funereal
-226209	furnishings
-198006	furthermore
-select fld3 from t2 where fld3 like "L%" and fld3 = "ok";
-fld3
-select fld3 from t2 where (fld3 like "C%" and fld3 = "Chantilly");
-fld3
-Chantilly
-select fld1,fld3 from t2 where fld1 like "25050%";
-fld1	fld3
-250501	poisoning
-250502	Iraqis
-250503	heaving
-250504	population
-250505	bomb
-select fld1,fld3 from t2 where fld1 like "25050_";
-fld1	fld3
-250501	poisoning
-250502	Iraqis
-250503	heaving
-250504	population
-250505	bomb
-select distinct companynr from t2;
-companynr
-0
-37
-36
-50
-58
-29
-40
-53
-65
-41
-34
-68
-select distinct companynr from t2 order by companynr;
-companynr
-0
-29
-34
-36
-37
-40
-41
-50
-53
-58
-65
-68
-select distinct companynr from t2 order by companynr desc;
-companynr
-68
-65
-58
-53
-50
-41
-40
-37
-36
-34
-29
-0
-select distinct t2.fld3,period from t2,t1 where companynr=37 and fld3 like "O%" ORDER BY t2.fld3,period;
-fld3	period
-obliterates	9410
-offload	9410
-opaquely	9410
-organizer	9410
-overestimating	9410
-overlay	9410
-select distinct fld3 from t2 where companynr = 34 order by fld3;
-fld3
-absentee
-accessed
-ahead
-alphabetic
-Asiaticizations
-attitude
-aye
-bankruptcies
-belays
-Blythe
-bomb
-boulevard
-bulldozes
-cannot
-caressing
-charcoal
-checksumming
-chess
-clubroom
-colorful
-cosy
-creator
-crying
-Darius
-diffusing
-duality
-Eiffel
-Epiphany
-Ernestine
-explorers
-exterminated
-famine
-forked
-Gershwins
-heaving
-Hodges
-Iraqis
-Italianization
-Lagos
-landslide
-libretto
-Majorca
-mastering
-narrowed
-occurred
-offerers
-Palestine
-Peruvianizes
-pharmaceutic
-poisoning
-population
-Pygmalion
-rats
-realest
-recording
-regimented
-retransmitting
-reviver
-rouses
-scars
-sicker
-sleepwalk
-stopped
-sugars
-translatable
-uncles
-unexpected
-uprisings
-versatility
-vest
-select distinct fld3 from t2 ORDER BY fld3 limit 10;
-fld3
-abates
-abiding
-Abraham
-abrogating
-absentee
-abut
-accessed
-accruing
-accumulating
-accuracies
-select distinct fld3 from t2 having fld3 like "A%" limit 10;
-fld3
-abates
-abiding
-Abraham
-abrogating
-absentee
-abut
-accessed
-accruing
-accumulating
-accuracies
-select distinct substring(fld3,1,3) from t2 where fld3 like "A%";
-substring(fld3,1,3)
-aba
-abi
-Abr
-abs
-abu
-acc
-acq
-acu
-Ade
-adj
-Adl
-adm
-Ado
-ads
-adv
-aer
-aff
-afi
-afl
-afo
-agi
-ahe
-aim
-air
-Ald
-alg
-ali
-all
-alp
-alr
-ama
-ame
-amm
-ana
-and
-ane
-Ang
-ani
-Ann
-Ant
-api
-app
-aqu
-Ara
-arc
-Arm
-arr
-Art
-Asi
-ask
-asp
-ass
-ast
-att
-aud
-Aug
-aut
-ave
-avo
-awe
-aye
-Azt
-select distinct lower(substring(fld3,1,3)) as a from t2 having a like "A%" order by a limit 10;
-a
-aba
-abi
-abr
-abs
-abu
-acc
-acq
-acu
-ade
-adj
-select distinct substring(fld3,1,3) from t2 where fld3 like "A%" limit 10;
-substring(fld3,1,3)
-aba
-abi
-Abr
-abs
-abu
-acc
-acq
-acu
-Ade
-adj
-create table t3 (
-period    int not null,
-name      char(32) not null,
-companynr int not null,
-price     double(11,0),
-price2     double(11,0),
-key (period),
-key (name)
-);
-create temporary table tmp engine = myisam select * from t3;
-insert into t3 select * from tmp;
-insert into tmp select * from t3;
-insert into t3 select * from tmp;
-insert into tmp select * from t3;
-insert into t3 select * from tmp;
-insert into tmp select * from t3;
-insert into t3 select * from tmp;
-insert into tmp select * from t3;
-insert into t3 select * from tmp;
-insert into tmp select * from t3;
-insert into t3 select * from tmp;
-insert into tmp select * from t3;
-insert into t3 select * from tmp;
-insert into tmp select * from t3;
-insert into t3 select * from tmp;
-insert into tmp select * from t3;
-insert into t3 select * from tmp;
-alter table t3 add t2nr int not null auto_increment primary key first;
-drop table tmp;
-select distinct concat(fld3," ",fld3) as namn from t2,t3 where t2.fld1=t3.t2nr order by namn limit 10;
-namn
-Abraham Abraham
-abrogating abrogating
-admonishing admonishing
-Adolph Adolph
-afield afield
-aging aging
-ammonium ammonium
-analyzable analyzable
-animals animals
-animized animized
-select distinct concat(fld3," ",fld3) from t2,t3 where t2.fld1=t3.t2nr order by fld3 limit 10;
-concat(fld3," ",fld3)
-Abraham Abraham
-abrogating abrogating
-admonishing admonishing
-Adolph Adolph
-afield afield
-aging aging
-ammonium ammonium
-analyzable analyzable
-animals animals
-animized animized
-select distinct fld5 from t2 limit 10;
-fld5
-neat
-Steinberg
-jarring
-tinily
-balled
-persist
-attainments
-fanatic
-measures
-rightfulness
-select distinct fld3,count(*) from t2 group by companynr,fld3 limit 10;
-fld3	count(*)
-affixed	1
-and	1
-annoyers	1
-Anthony	1
-assayed	1
-assurers	1
-attendants	1
-bedlam	1
-bedpost	1
-boasted	1
-select distinct fld3,count(*) from t2 group by companynr,fld3 limit 10;
-fld3	count(*)
-affixed	1
-and	1
-annoyers	1
-Anthony	1
-assayed	1
-assurers	1
-attendants	1
-bedlam	1
-bedpost	1
-boasted	1
-select distinct fld3,repeat("a",length(fld3)),count(*) from t2 group by companynr,fld3 limit 100,10;
-fld3	repeat("a",length(fld3))	count(*)
-circus	aaaaaa	1
-cited	aaaaa	1
-Colombo	aaaaaaa	1
-congresswoman	aaaaaaaaaaaaa	1
-contrition	aaaaaaaaaa	1
-corny	aaaaa	1
-cultivation	aaaaaaaaaaa	1
-definiteness	aaaaaaaaaaaa	1
-demultiplex	aaaaaaaaaaa	1
-disappointing	aaaaaaaaaaaaa	1
-select distinct companynr,rtrim(space(512+companynr)) from t3 order by 1,2;
-companynr	rtrim(space(512+companynr))
-37	
-78	
-101	
-154	
-311	
-447	
-512	
-select distinct fld3 from t2,t3 where t2.companynr = 34 and t2.fld1=t3.t2nr order by fld3;
-fld3
-explain select t3.t2nr,fld3 from t2,t3 where t2.companynr = 34 and t2.fld1=t3.t2nr order by t3.t2nr,fld3;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	ALL	fld1	NULL	NULL	NULL	#	Using where; Using temporary; Using filesort
-1	SIMPLE	t3	eq_ref	PRIMARY	PRIMARY	4	test.t2.fld1	#	Using index
-explain select * from t3 as t1,t3 where t1.period=t3.period order by t3.period;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t1	ALL	period	NULL	NULL	NULL	#	Using temporary; Using filesort
-1	SIMPLE	t3	ref	period	period	4	test.t1.period	#	
-explain select * from t3 as t1,t3 where t1.period=t3.period order by t3.period limit 10;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t3	index	period	period	4	NULL	#	
-1	SIMPLE	t1	ref	period	period	4	test.t3.period	#	
-explain select * from t3 as t1,t3 where t1.period=t3.period order by t1.period limit 10;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t1	index	period	period	4	NULL	#	
-1	SIMPLE	t3	ref	period	period	4	test.t1.period	#	
-select period from t1;
-period
-9410
-select period from t1 where period=1900;
-period
-select fld3,period from t1,t2 where fld1 = 011401 order by period;
-fld3	period
-breaking	9410
-select fld3,period from t2,t3 where t2.fld1 = 011401 and t2.fld1=t3.t2nr and t3.period=1001;
-fld3	period
-breaking	1001
-explain select fld3,period from t2,t3 where t2.fld1 = 011401 and t3.t2nr=t2.fld1 and 1001 = t3.period;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	const	fld1	fld1	4	const	#	
-1	SIMPLE	t3	const	PRIMARY,period	PRIMARY	4	const	#	
-select fld3,period from t2,t1 where companynr*10 = 37*10;
-fld3	period
-Abraham	9410
-Aden	9410
-Adolph	9410
-Aldrich	9410
-Alison	9410
-Anatole	9410
-Antarctica	9410
-Antares	9410
-Arabia	9410
-Artemia	9410
-Augustine	9410
-Baird	9410
-Beebe	9410
-Butterfield	9410
-CERN	9410
-Cassites	9410
-Chicana	9410
-Chippewa	9410
-Clayton	9410
-Conley	9410
-Connally	9410
-Crays	9410
-DiMaggio	9410
-Dutchman	9410
-Eulerian	9410
-Evanston	9410
-Everhart	9410
-Fenton	9410
-Fitzpatrick	9410
-Galatean	9410
-Gandhian	9410
-Ganymede	9410
-Goldstine	9410
-Gothicism	9410
-Graves	9410
-Greenberg	9410
-Gurkha	9410
-Hawaii	9410
-Hegelian	9410
-Hornblower	9410
-Huffman	9410
-Hunter	9410
-Joplin	9410
-Judas	9410
-Kane	9410
-Kantian	9410
-Kevin	9410
-Kinsey	9410
-Kline	9410
-Lars	9410
-Latinizes	9410
-Lillian	9410
-Lizzy	9410
-Majorca	9410
-Manhattanize	9410
-McGovern	9410
-Melinda	9410
-Merritt	9410
-Micronesia	9410
-Miles	9410
-Miltonism	9410
-Nabisco	9410
-Nazis	9410
-Newtonian	9410
-Norwalk	9410
-Pandora	9410
-Parsifal	9410
-Peruvian	9410
-Punjab	9410
-Pyle	9410
-Quixotism	9410
-Romano	9410
-Romans	9410
-Sabine	9410
-Sault	9410
-Saxony	9410
-Selfridge	9410
-Shanghais	9410
-Simla	9410
-Simon	9410
-Stalin	9410
-Steinberg	9410
-Taoism	9410
-Teresa	9410
-Tipperary	9410
-Weissmuller	9410
-Winsett	9410
-Wotan	9410
-abates	9410
-abrogating	9410
-accessed	9410
-admiring	9410
-admonishing	9410
-afield	9410
-afore	9410
-aging	9410
-airships	9410
-alike	9410
-allot	9410
-already	9410
-amenities	9410
-ammonium	9410
-analogy	9410
-analyzable	9410
-animals	9410
-animized	9410
-annihilates	9410
-announced	9410
-announces	9410
-apiary	9410
-appendixes	9410
-appendixes	9410
-appendixes	9410
-appendixes	9410
-appendixes	9410
-appendixes	9410
-arriving	9410
-arteriole	9410
-assails	9410
-astound	9410
-attainments	9410
-attrition	9410
-audiology	9410
-avenge	9410
-avoidable	9410
-babies	9410
-babysitting	9410
-balled	9410
-beaner	9410
-beaters	9410
-bee	9410
-befouled	9410
-bellow	9410
-bestseller	9410
-betroth	9410
-bewilderingly	9410
-bills	9410
-bitterroot	9410
-bivalves	9410
-bloater	9410
-bloodbath	9410
-boat	9410
-boom	9410
-boorish	9410
-boulder	9410
-breaking	9410
-brunch	9410
-buckboards	9410
-burlesque	9410
-cage	9410
-capably	9410
-capped	9410
-cascade	9410
-causality	9410
-cautioned	9410
-ceiling	9410
-celery	9410
-certificates	9410
-chafe	9410
-chaperone	9410
-charges	9410
-chasm	9410
-checkpoints	9410
-chewing	9410
-chews	9410
-chillingly	9410
-chronicle	9410
-ciphers	9410
-civics	9410
-clamored	9410
-clenched	9410
-clockers	9410
-coexist	9410
-cokes	9410
-combed	9410
-coming	9410
-commencements	9410
-commonplace	9410
-communicants	9410
-compartment	9410
-comprehensive	9410
-comprised	9410
-conceptions	9410
-concludes	9410
-congregates	9410
-contrary	9410
-contrasted	9410
-convenient	9410
-convulsion	9410
-corset	9410
-count	9410
-coverings	9410
-craziness	9410
-creak	9410
-creek	9410
-critiques	9410
-crunches	9410
-culled	9410
-cult	9410
-cupboard	9410
-cured	9410
-cute	9410
-daughter	9410
-decliner	9410
-decomposition	9410
-deductions	9410
-dehydrate	9410
-deludes	9410
-denizen	9410
-denotative	9410
-denounces	9410
-dental	9410
-dentally	9410
-descendants	9410
-despot	9410
-destroyer	9410
-detectably	9410
-dialysis	9410
-dimensions	9410
-disable	9410
-discounts	9410
-disentangle	9410
-disobedience	9410
-dissociate	9410
-dogging	9410
-dopers	9410
-drains	9410
-dreaded	9410
-ducks	9410
-dusted	9410
-effortlessly	9410
-electroencephalography	9410
-elite	9410
-embassies	9410
-employing	9410
-encompass	9410
-encompasses	9410
-environing	9410
-epistle	9410
-equilibrium	9410
-erases	9410
-error	9410
-eschew	9410
-eternal	9410
-evened	9410
-evenhandedly	9410
-eventful	9410
-excises	9410
-exclamation	9410
-excrete	9410
-exhausts	9410
-expelled	9410
-extents	9410
-externally	9410
-extracted	9410
-faithful	9410
-fanatic	9410
-fated	9410
-featherweight	9410
-feed	9410
-feminine	9410
-fetched	9410
-fetters	9410
-fiftieth	9410
-filial	9410
-fingerings	9410
-finishers	9410
-firearm	9410
-fitting	9410
-fixedly	9410
-flanking	9410
-flint	9410
-flopping	9410
-flurried	9410
-foldout	9410
-foothill	9410
-forgivably	9410
-forthcoming	9410
-freakish	9410
-freest	9410
-freezes	9410
-funereal	9410
-furnishings	9410
-furthermore	9410
-gadfly	9410
-gainful	9410
-galling	9410
-garage	9410
-gentleman	9410
-gifted	9410
-gleaning	9410
-glut	9410
-goblins	9410
-governing	9410
-gradually	9410
-grazing	9410
-gritty	9410
-groupings	9410
-guides	9410
-guitars	9410
-handgun	9410
-handy	9410
-heiress	9410
-hoarder	9410
-honoring	9410
-hostess	9410
-humanness	9410
-humiliation	9410
-humility	9410
-hushes	9410
-husky	9410
-hypothesizer	9410
-icon	9410
-ideas	9410
-impelling	9410
-impending	9410
-imperial	9410
-imperiously	9410
-imprint	9410
-impulsive	9410
-inaccuracy	9410
-inch	9410
-incidentals	9410
-incorrectly	9410
-incurring	9410
-index	9410
-indulge	9410
-indulgences	9410
-ineffective	9410
-infallibly	9410
-infest	9410
-inform	9410
-inmate	9410
-insolence	9410
-instruments	9410
-intelligibility	9410
-intentness	9410
-intercepted	9410
-interdependent	9410
-interrelationships	9410
-interrogate	9410
-investigations	9410
-irresponsibly	9410
-jarring	9410
-journalizing	9410
-juveniles	9410
-kanji	9410
-kingdom	9410
-kiting	9410
-labeled	9410
-languages	9410
-laterally	9410
-lawgiver	9410
-leaflet	9410
-leavings	9410
-lectured	9410
-leftover	9410
-lewdly	9410
-lied	9410
-linear	9410
-lists	9410
-lithograph	9410
-lore	9410
-luckily	9410
-males	9410
-marginal	9410
-mastering	9410
-mayoral	9410
-meanwhile	9410
-measures	9410
-measures	9410
-mechanizing	9410
-medical	9410
-meditation	9410
-metaphysically	9410
-mineral	9410
-miniaturizes	9410
-minima	9410
-minion	9410
-minting	9410
-misted	9410
-misunderstander	9410
-mixture	9410
-motors	9410
-mournfulness	9410
-multilayer	9410
-mumbles	9410
-mushrooms	9410
-mystic	9410
-navies	9410
-navigate	9410
-neat	9410
-neonatal	9410
-nested	9410
-noncritical	9410
-normalizes	9410
-obliterates	9410
-offload	9410
-opaquely	9410
-organizer	9410
-overestimating	9410
-overlay	9410
-parametrized	9410
-parenthood	9410
-parters	9410
-participated	9410
-partridges	9410
-peacock	9410
-peeked	9410
-pellagra	9410
-percentage	9410
-percentage	9410
-persist	9410
-perturb	9410
-pessimist	9410
-pests	9410
-petted	9410
-pictures	9410
-pithed	9410
-pityingly	9410
-poison	9410
-posed	9410
-positioning	9410
-postulation	9410
-praised	9410
-precaution	9410
-precipitable	9410
-preclude	9410
-presentation	9410
-pressure	9410
-previewing	9410
-priceless	9410
-primary	9410
-psychic	9410
-publicly	9410
-puddings	9410
-quagmire	9410
-quitter	9410
-railway	9410
-raining	9410
-rains	9410
-ravines	9410
-readable	9410
-realized	9410
-realtor	9410
-reassigned	9410
-recruited	9410
-reduce	9410
-regimented	9410
-registration	9410
-relatively	9410
-relaxing	9410
-relishing	9410
-relives	9410
-renew	9410
-repelled	9410
-repetitions	9410
-reporters	9410
-reporters	9410
-repressions	9410
-resplendent	9410
-resumes	9410
-rifles	9410
-rightful	9410
-rightfully	9410
-rightfulness	9410
-ripeness	9410
-riser	9410
-roped	9410
-rudeness	9410
-rules	9410
-rural	9410
-rusting	9410
-sadly	9410
-sags	9410
-sanding	9410
-saplings	9410
-sating	9410
-save	9410
-sawtooth	9410
-scarf	9410
-scatterbrain	9410
-scheduling	9410
-schemer	9410
-scholastics	9410
-scornfully	9410
-secures	9410
-securing	9410
-seminaries	9410
-serializations	9410
-serpents	9410
-serving	9410
-severely	9410
-sews	9410
-shapelessly	9410
-shipyard	9410
-shooter	9410
-similarities	9410
-skulking	9410
-slaughter	9410
-sloping	9410
-smoothed	9410
-snatching	9410
-socializes	9410
-sophomore	9410
-sorters	9410
-spatial	9410
-specification	9410
-specifics	9410
-spongers	9410
-spools	9410
-sportswriting	9410
-sporty	9410
-squabbled	9410
-squeaking	9410
-squeezes	9410
-stabilizes	9410
-stairway	9410
-standardizes	9410
-star	9410
-starlet	9410
-stated	9410
-stint	9410
-stodgy	9410
-store	9410
-straight	9410
-stranglings	9410
-subdirectory	9410
-subjective	9410
-subschema	9410
-succumbed	9410
-suites	9410
-sumac	9410
-sureties	9410
-swaying	9410
-sweetish	9410
-swelling	9410
-syndicate	9410
-taxonomically	9410
-techniques	9410
-teem	9410
-teethe	9410
-tempering	9410
-terminal	9410
-terminator	9410
-terminators	9410
-test	9410
-testicle	9410
-textures	9410
-theorizers	9410
-throttles	9410
-tidiness	9410
-timesharing	9410
-tinily	9410
-tinting	9410
-title	9410
-tragedies	9410
-traitor	9410
-trimmings	9410
-tropics	9410
-unaffected	9410
-uncovering	9410
-undoes	9410
-ungrateful	9410
-universals	9410
-unplug	9410
-unruly	9410
-untying	9410
-unwilling	9410
-vacuuming	9410
-validate	9410
-vanish	9410
-ventilate	9410
-veranda	9410
-vests	9410
-wallet	9410
-waltz	9410
-warm	9410
-warningly	9410
-watering	9410
-weasels	9410
-western	9410
-whiteners	9410
-widens	9410
-witchcraft	9410
-workers	9410
-yelped	9410
-youthfulness	9410
-select fld3,period,price,price2 from t2,t3 where t2.fld1=t3.t2nr and period >= 1001 and period <= 1002 and t2.companynr = 37 order by fld3,period, price;
-fld3	period	price	price2
-admonishing	1002	28357832	8723648
-analyzable	1002	28357832	8723648
-annihilates	1001	5987435	234724
-Antares	1002	28357832	8723648
-astound	1001	5987435	234724
-audiology	1001	5987435	234724
-Augustine	1002	28357832	8723648
-Baird	1002	28357832	8723648
-bewilderingly	1001	5987435	234724
-breaking	1001	5987435	234724
-Conley	1001	5987435	234724
-dentally	1002	28357832	8723648
-dissociate	1002	28357832	8723648
-elite	1001	5987435	234724
-eschew	1001	5987435	234724
-Eulerian	1001	5987435	234724
-flanking	1001	5987435	234724
-foldout	1002	28357832	8723648
-funereal	1002	28357832	8723648
-galling	1002	28357832	8723648
-Graves	1001	5987435	234724
-grazing	1001	5987435	234724
-groupings	1001	5987435	234724
-handgun	1001	5987435	234724
-humility	1002	28357832	8723648
-impulsive	1002	28357832	8723648
-inch	1001	5987435	234724
-intelligibility	1001	5987435	234724
-jarring	1001	5987435	234724
-lawgiver	1001	5987435	234724
-lectured	1002	28357832	8723648
-Merritt	1002	28357832	8723648
-neonatal	1001	5987435	234724
-offload	1002	28357832	8723648
-parters	1002	28357832	8723648
-pityingly	1002	28357832	8723648
-puddings	1002	28357832	8723648
-Punjab	1001	5987435	234724
-quitter	1002	28357832	8723648
-realtor	1001	5987435	234724
-relaxing	1001	5987435	234724
-repetitions	1001	5987435	234724
-resumes	1001	5987435	234724
-Romans	1002	28357832	8723648
-rusting	1001	5987435	234724
-scholastics	1001	5987435	234724
-skulking	1002	28357832	8723648
-stated	1002	28357832	8723648
-suites	1002	28357832	8723648
-sureties	1001	5987435	234724
-testicle	1002	28357832	8723648
-tinily	1002	28357832	8723648
-tragedies	1001	5987435	234724
-trimmings	1001	5987435	234724
-vacuuming	1001	5987435	234724
-ventilate	1001	5987435	234724
-wallet	1001	5987435	234724
-Weissmuller	1002	28357832	8723648
-Wotan	1002	28357832	8723648
-select t2.fld1,fld3,period,price,price2 from t2,t3 where t2.fld1>= 18201 and t2.fld1 <= 18811 and t2.fld1=t3.t2nr and period = 1001 and t2.companynr = 37;
-fld1	fld3	period	price	price2
-18201	relaxing	1001	5987435	234724
-18601	vacuuming	1001	5987435	234724
-18801	inch	1001	5987435	234724
-18811	repetitions	1001	5987435	234724
-create temporary table t4 (
-companynr int NOT NULL default '00',
-companyname char(30) NOT NULL default '',
-PRIMARY KEY (companynr),
-UNIQUE KEY companyname(companyname)
-) ENGINE=MyISAM COMMENT='companynames';
-select STRAIGHT_JOIN t2.companynr,companyname from t4,t2 where t2.companynr=t4.companynr group by t2.companynr;
-companynr	companyname
-0	Unknown
-29	company 1
-34	company 2
-36	company 3
-37	company 4
-40	company 5
-41	company 6
-50	company 11
-53	company 7
-58	company 8
-65	company 9
-68	company 10
-select SQL_SMALL_RESULT t2.companynr,companyname from t4,t2 where t2.companynr=t4.companynr group by t2.companynr;
-companynr	companyname
-0	Unknown
-29	company 1
-34	company 2
-36	company 3
-37	company 4
-40	company 5
-41	company 6
-50	company 11
-53	company 7
-58	company 8
-65	company 9
-68	company 10
-select * from t1,t1 t12;
-Period	Varor_period	Period	Varor_period
-9410	9412	9410	9412
-select t2.fld1,t22.fld1 from t2,t2 t22 where t2.fld1 >= 250501 and t2.fld1 <= 250505 and t22.fld1 >= 250501 and t22.fld1 <= 250505;
-fld1	fld1
-250501	250501
-250502	250501
-250503	250501
-250504	250501
-250505	250501
-250501	250502
-250502	250502
-250503	250502
-250504	250502
-250505	250502
-250501	250503
-250502	250503
-250503	250503
-250504	250503
-250505	250503
-250501	250504
-250502	250504
-250503	250504
-250504	250504
-250505	250504
-250501	250505
-250502	250505
-250503	250505
-250504	250505
-250505	250505
-insert into t2 (fld1, companynr) values (999999,99);
-select t2.companynr,companyname from t2 left join t4 using (companynr) where t4.companynr is null;
-companynr	companyname
-99	NULL
-select count(*) from t2 left join t4 using (companynr) where t4.companynr is not null;
-count(*)
-1199
-explain select t2.companynr,companyname from t2 left join t4 using (companynr) where t4.companynr is null;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	
-1	SIMPLE	t4	eq_ref	PRIMARY	PRIMARY	4	test.t2.companynr	#	Using where; Not exists
-explain select t2.companynr,companyname from t4 left join t2 using (companynr) where t2.companynr is null;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t4	ALL	NULL	NULL	NULL	NULL	#	
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	Using where; Not exists
-select companynr,companyname from t2 left join t4 using (companynr) where companynr is null;
-companynr	companyname
-select count(*) from t2 left join t4 using (companynr) where companynr is not null;
-count(*)
-1200
-explain select companynr,companyname from t2 left join t4 using (companynr) where companynr is null;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	NULL	NULL	NULL	NULL	NULL	NULL	#	Impossible WHERE
-explain select companynr,companyname from t4 left join t2 using (companynr) where companynr is null;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	NULL	NULL	NULL	NULL	NULL	NULL	#	Impossible WHERE
-delete from t2 where fld1=999999;
-explain select t2.companynr,companyname from t4 left join t2 using (companynr) where t2.companynr > 0;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	Using where
-1	SIMPLE	t4	eq_ref	PRIMARY	PRIMARY	4	test.t2.companynr	#	
-explain select t2.companynr,companyname from t4 left join t2 using (companynr) where t2.companynr > 0 or t2.companynr < 0;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	Using where
-1	SIMPLE	t4	eq_ref	PRIMARY	PRIMARY	4	test.t2.companynr	#	
-explain select t2.companynr,companyname from t4 left join t2 using (companynr) where t2.companynr > 0 and t4.companynr > 0;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	Using where
-1	SIMPLE	t4	eq_ref	PRIMARY	PRIMARY	4	test.t2.companynr	#	
-explain select companynr,companyname from t4 left join t2 using (companynr) where companynr > 0;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t4	ALL	PRIMARY	NULL	NULL	NULL	#	Using where
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	
-explain select companynr,companyname from t4 left join t2 using (companynr) where companynr > 0 or companynr < 0;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t4	ALL	PRIMARY	NULL	NULL	NULL	#	Using where
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	
-explain select companynr,companyname from t4 left join t2 using (companynr) where companynr > 0 and companynr > 0;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t4	ALL	PRIMARY	NULL	NULL	NULL	#	Using where
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	
-explain select t2.companynr,companyname from t4 left join t2 using (companynr) where t2.companynr > 0 or t2.companynr is null;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t4	ALL	NULL	NULL	NULL	NULL	#	
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	Using where
-explain select t2.companynr,companyname from t4 left join t2 using (companynr) where t2.companynr > 0 or t2.companynr < 0 or t4.companynr > 0;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t4	ALL	PRIMARY	NULL	NULL	NULL	#	
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	Using where
-explain select t2.companynr,companyname from t4 left join t2 using (companynr) where ifnull(t2.companynr,1)>0;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t4	ALL	NULL	NULL	NULL	NULL	#	
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	Using where
-explain select companynr,companyname from t4 left join t2 using (companynr) where companynr > 0 or companynr is null;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t4	ALL	PRIMARY	NULL	NULL	NULL	#	Using where
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	
-explain select companynr,companyname from t4 left join t2 using (companynr) where companynr > 0 or companynr < 0 or companynr > 0;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t4	ALL	PRIMARY	NULL	NULL	NULL	#	Using where
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	
-explain select companynr,companyname from t4 left join t2 using (companynr) where ifnull(companynr,1)>0;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t4	ALL	NULL	NULL	NULL	NULL	#	Using where
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	
-select distinct t2.companynr,t4.companynr from t2,t4 where t2.companynr=t4.companynr+1;
-companynr	companynr
-37	36
-41	40
-explain select distinct t2.companynr,t4.companynr from t2,t4 where t2.companynr=t4.companynr+1;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t4	index	NULL	PRIMARY	4	NULL	#	Using index; Using temporary
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	Using where; Using join buffer
-select t2.fld1,t2.companynr,fld3,period from t3,t2 where t2.fld1 = 38208 and t2.fld1=t3.t2nr and period = 1008 or t2.fld1 = 38008 and t2.fld1 =t3.t2nr and period = 1008;
-fld1	companynr	fld3	period
-38008	37	reporters	1008
-38208	37	Selfridge	1008
-select t2.fld1,t2.companynr,fld3,period from t3,t2 where (t2.fld1 = 38208 or t2.fld1 = 38008) and t2.fld1=t3.t2nr and period>=1008 and period<=1009;
-fld1	companynr	fld3	period
-38008	37	reporters	1008
-38208	37	Selfridge	1008
-select t2.fld1,t2.companynr,fld3,period from t3,t2 where (t3.t2nr = 38208 or t3.t2nr = 38008) and t2.fld1=t3.t2nr and period>=1008 and period<=1009;
-fld1	companynr	fld3	period
-38008	37	reporters	1008
-38208	37	Selfridge	1008
-select period from t1 where (((period > 0) or period < 10000 or (period = 1900)) and (period=1900 and period <= 1901) or (period=1903 and (period=1903)) and period>=1902) or ((period=1904 or period=1905) or (period=1906 or period>1907)) or (period=1908 and period = 1909);
-period
-9410
-select period from t1 where ((period > 0 and period < 1) or (((period > 0 and period < 100) and (period > 10)) or (period > 10)) or (period > 0 and (period > 5 or period > 6)));
-period
-9410
-select a.fld1 from t2 as a,t2 b where ((a.fld1 = 250501 and a.fld1=b.fld1) or a.fld1=250502 or a.fld1=250503 or (a.fld1=250505 and a.fld1<=b.fld1 and b.fld1>=a.fld1)) and a.fld1=b.fld1;
-fld1
-250501
-250502
-250503
-250505
-select fld1 from t2 where fld1 in (250502,98005,98006,250503,250605,250606) and fld1 >=250502 and fld1 not in (250605,250606);
-fld1
-250502
-250503
-select fld1 from t2 where fld1 between 250502 and 250504;
-fld1
-250502
-250503
-250504
-select fld3 from t2 where (((fld3 like "_%L%" ) or (fld3 like "%ok%")) and ( fld3 like "L%" or fld3 like "G%")) and fld3 like "L%" ;
-fld3
-label
-labeled
-labeled
-landslide
-laterally
-leaflet
-lewdly
-Lillian
-luckily
-select count(*) from t1;
-count(*)
-1
-select companynr,count(*),sum(fld1) from t2 group by companynr;
-companynr	count(*)	sum(fld1)
-0	82	10355753
-29	95	14473298
-34	70	17788966
-36	215	22786296
-37	588	83602098
-40	37	6618386
-41	52	12816335
-50	11	1595438
-53	4	793210
-58	23	2254293
-65	10	2284055
-68	12	3097288
-select companynr,count(*) from t2 group by companynr order by companynr desc limit 5;
-companynr	count(*)
-68	12
-65	10
-58	23
-53	4
-50	11
-select count(*),min(fld4),max(fld4),sum(fld1),avg(fld1),std(fld1),variance(fld1) from t2 where companynr = 34 and fld4<>"";
-count(*)	min(fld4)	max(fld4)	sum(fld1)	avg(fld1)	std(fld1)	variance(fld1)
-70	absentee	vest	17788966	254128.0857	3272.5940	10709871.3069
-explain extended select count(*),min(fld4),max(fld4),sum(fld1),avg(fld1),std(fld1),variance(fld1) from t2 where companynr = 34 and fld4<>"";
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	filtered	Extra
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	100.00	Using where
-Warnings:
-Note	1003	select count(0) AS `count(*)`,min(`test`.`t2`.`fld4`) AS `min(fld4)`,max(`test`.`t2`.`fld4`) AS `max(fld4)`,sum(`test`.`t2`.`fld1`) AS `sum(fld1)`,avg(`test`.`t2`.`fld1`) AS `avg(fld1)`,std(`test`.`t2`.`fld1`) AS `std(fld1)`,variance(`test`.`t2`.`fld1`) AS `variance(fld1)` from `test`.`t2` where ((`test`.`t2`.`companynr` = 34) and (`test`.`t2`.`fld4` <> ''))
-select companynr,count(*),min(fld4),max(fld4),sum(fld1),avg(fld1),std(fld1),variance(fld1) from t2 group by companynr limit 3;
-companynr	count(*)	min(fld4)	max(fld4)	sum(fld1)	avg(fld1)	std(fld1)	variance(fld1)
-0	82	Anthony	windmills	10355753	126289.6707	115550.9757	13352027981.7087
-29	95	abut	wetness	14473298	152350.5053	8368.5480	70032594.9026
-34	70	absentee	vest	17788966	254128.0857	3272.5940	10709871.3069
-select companynr,t2nr,count(price),sum(price),min(price),max(price),avg(price) from t3 where companynr = 37 group by companynr,t2nr limit 10;
-companynr	t2nr	count(price)	sum(price)	min(price)	max(price)	avg(price)
-37	1	1	5987435	5987435	5987435	5987435.0000
-37	2	1	28357832	28357832	28357832	28357832.0000
-37	3	1	39654943	39654943	39654943	39654943.0000
-37	11	1	5987435	5987435	5987435	5987435.0000
-37	12	1	28357832	28357832	28357832	28357832.0000
-37	13	1	39654943	39654943	39654943	39654943.0000
-37	21	1	5987435	5987435	5987435	5987435.0000
-37	22	1	28357832	28357832	28357832	28357832.0000
-37	23	1	39654943	39654943	39654943	39654943.0000
-37	31	1	5987435	5987435	5987435	5987435.0000
-select /*! SQL_SMALL_RESULT */ companynr,t2nr,count(price),sum(price),min(price),max(price),avg(price) from t3 where companynr = 37 group by companynr,t2nr limit 10;
-companynr	t2nr	count(price)	sum(price)	min(price)	max(price)	avg(price)
-37	1	1	5987435	5987435	5987435	5987435.0000
-37	2	1	28357832	28357832	28357832	28357832.0000
-37	3	1	39654943	39654943	39654943	39654943.0000
-37	11	1	5987435	5987435	5987435	5987435.0000
-37	12	1	28357832	28357832	28357832	28357832.0000
-37	13	1	39654943	39654943	39654943	39654943.0000
-37	21	1	5987435	5987435	5987435	5987435.0000
-37	22	1	28357832	28357832	28357832	28357832.0000
-37	23	1	39654943	39654943	39654943	39654943.0000
-37	31	1	5987435	5987435	5987435	5987435.0000
-select companynr,count(price),sum(price),min(price),max(price),avg(price) from t3 group by companynr ;
-companynr	count(price)	sum(price)	min(price)	max(price)	avg(price)
-37	12543	309394878010	5987435	39654943	24666736.6667
-78	8362	414611089292	726498	98439034	49582766.0000
-101	4181	3489454238	834598	834598	834598.0000
-154	4181	4112197254950	983543950	983543950	983543950.0000
-311	4181	979599938	234298	234298	234298.0000
-447	4181	9929180954	2374834	2374834	2374834.0000
-512	4181	3288532102	786542	786542	786542.0000
-select distinct mod(companynr,10) from t4 group by companynr;
-mod(companynr,10)
-0
-9
-4
-6
-7
-1
-3
-8
-5
-select distinct 1 from t4 group by companynr;
-1
-1
-select count(distinct fld1) from t2;
-count(distinct fld1)
-1199
-select companynr,count(distinct fld1) from t2 group by companynr;
-companynr	count(distinct fld1)
-0	82
-29	95
-34	70
-36	215
-37	588
-40	37
-41	52
-50	11
-53	4
-58	23
-65	10
-68	12
-select companynr,count(*) from t2 group by companynr;
-companynr	count(*)
-0	82
-29	95
-34	70
-36	215
-37	588
-40	37
-41	52
-50	11
-53	4
-58	23
-65	10
-68	12
-select companynr,count(distinct concat(fld1,repeat(65,1000))) from t2 group by companynr;
-companynr	count(distinct concat(fld1,repeat(65,1000)))
-0	82
-29	95
-34	70
-36	215
-37	588
-40	37
-41	52
-50	11
-53	4
-58	23
-65	10
-68	12
-select companynr,count(distinct concat(fld1,repeat(65,200))) from t2 group by companynr;
-companynr	count(distinct concat(fld1,repeat(65,200)))
-0	82
-29	95
-34	70
-36	215
-37	588
-40	37
-41	52
-50	11
-53	4
-58	23
-65	10
-68	12
-select companynr,count(distinct floor(fld1/100)) from t2 group by companynr;
-companynr	count(distinct floor(fld1/100))
-0	47
-29	35
-34	14
-36	69
-37	108
-40	16
-41	11
-50	9
-53	1
-58	1
-65	1
-68	1
-select companynr,count(distinct concat(repeat(65,1000),floor(fld1/100))) from t2 group by companynr;
-companynr	count(distinct concat(repeat(65,1000),floor(fld1/100)))
-0	47
-29	35
-34	14
-36	69
-37	108
-40	16
-41	11
-50	9
-53	1
-58	1
-65	1
-68	1
-select sum(fld1),fld3 from t2 where fld3="Romans" group by fld1 limit 10;
-sum(fld1)	fld3
-11402	Romans
-select name,count(*) from t3 where name='cloakroom' group by name;
-name	count(*)
-cloakroom	4181
-select name,count(*) from t3 where name='cloakroom' and price>10 group by name;
-name	count(*)
-cloakroom	4181
-select count(*) from t3 where name='cloakroom' and price2=823742;
-count(*)
-4181
-select name,count(*) from t3 where name='cloakroom' and price2=823742 group by name;
-name	count(*)
-cloakroom	4181
-select name,count(*) from t3 where name >= "extramarital" and price <= 39654943 group by name;
-name	count(*)
-extramarital	4181
-gazer	4181
-gems	4181
-Iranizes	4181
-spates	4181
-tucked	4181
-violinist	4181
-select t2.fld3,count(*) from t2,t3 where t2.fld1=158402 and t3.name=t2.fld3 group by t3.name;
-fld3	count(*)
-spates	4181
-select companynr,companyname from t4 group by 1;
-companynr	companyname
-0	Unknown
-29	company 1
-34	company 2
-36	company 3
-37	company 4
-40	company 5
-41	company 6
-50	company 11
-53	company 7
-58	company 8
-65	company 9
-68	company 10
-select t2.companynr,companyname,count(*) from t2,t4 where t2.companynr=t4.companynr group by t2.companynr order by companyname;
-companynr	companyname	count(*)
-29	company 1	95
-68	company 10	12
-50	company 11	11
-34	company 2	70
-36	company 3	215
-37	company 4	588
-40	company 5	37
-41	company 6	52
-53	company 7	4
-58	company 8	23
-65	company 9	10
-0	Unknown	82
-select t2.fld1,count(*) from t2,t3 where t2.fld1=158402 and t3.name=t2.fld3 group by t3.name;
-fld1	count(*)
-158402	4181
-select sum(Period)/count(*) from t1;
-sum(Period)/count(*)
-9410.0000
-select companynr,count(price) as "count",sum(price) as "sum" ,abs(sum(price)/count(price)-avg(price)) as "diff",(0+count(price))*companynr as func from t3 group by companynr;
-companynr	count	sum	diff	func
-37	12543	309394878010	0.0000	464091
-78	8362	414611089292	0.0000	652236
-101	4181	3489454238	0.0000	422281
-154	4181	4112197254950	0.0000	643874
-311	4181	979599938	0.0000	1300291
-447	4181	9929180954	0.0000	1868907
-512	4181	3288532102	0.0000	2140672
-select companynr,sum(price)/count(price) as avg from t3 group by companynr having avg > 70000000 order by avg;
-companynr	avg
-154	983543950.0000
-select companynr,count(*) from t2 group by companynr order by 2 desc;
-companynr	count(*)
-37	588
-36	215
-29	95
-0	82
-34	70
-41	52
-40	37
-58	23
-68	12
-50	11
-65	10
-53	4
-select companynr,count(*) from t2 where companynr > 40 group by companynr order by 2 desc;
-companynr	count(*)
-41	52
-58	23
-68	12
-50	11
-65	10
-53	4
-select t2.fld4,t2.fld1,count(price),sum(price),min(price),max(price),avg(price) from t3,t2 where t3.companynr = 37 and t2.fld1 = t3.t2nr group by fld1,t2.fld4;
-fld4	fld1	count(price)	sum(price)	min(price)	max(price)	avg(price)
-teethe	1	1	5987435	5987435	5987435	5987435.0000
-dreaded	11401	1	5987435	5987435	5987435	5987435.0000
-scholastics	11402	1	28357832	28357832	28357832	28357832.0000
-audiology	11403	1	39654943	39654943	39654943	39654943.0000
-wallet	11501	1	5987435	5987435	5987435	5987435.0000
-parters	11701	1	5987435	5987435	5987435	5987435.0000
-eschew	11702	1	28357832	28357832	28357832	28357832.0000
-quitter	11703	1	39654943	39654943	39654943	39654943.0000
-neat	12001	1	5987435	5987435	5987435	5987435.0000
-Steinberg	12003	1	39654943	39654943	39654943	39654943.0000
-balled	12301	1	5987435	5987435	5987435	5987435.0000
-persist	12302	1	28357832	28357832	28357832	28357832.0000
-attainments	12303	1	39654943	39654943	39654943	39654943.0000
-capably	12501	1	5987435	5987435	5987435	5987435.0000
-impulsive	12602	1	28357832	28357832	28357832	28357832.0000
-starlet	12603	1	39654943	39654943	39654943	39654943.0000
-featherweight	12701	1	5987435	5987435	5987435	5987435.0000
-pessimist	12702	1	28357832	28357832	28357832	28357832.0000
-daughter	12703	1	39654943	39654943	39654943	39654943.0000
-lawgiver	13601	1	5987435	5987435	5987435	5987435.0000
-stated	13602	1	28357832	28357832	28357832	28357832.0000
-readable	13603	1	39654943	39654943	39654943	39654943.0000
-testicle	13801	1	5987435	5987435	5987435	5987435.0000
-Parsifal	13802	1	28357832	28357832	28357832	28357832.0000
-leavings	13803	1	39654943	39654943	39654943	39654943.0000
-squeaking	13901	1	5987435	5987435	5987435	5987435.0000
-contrasted	16001	1	5987435	5987435	5987435	5987435.0000
-leftover	16201	1	5987435	5987435	5987435	5987435.0000
-whiteners	16202	1	28357832	28357832	28357832	28357832.0000
-erases	16301	1	5987435	5987435	5987435	5987435.0000
-Punjab	16302	1	28357832	28357832	28357832	28357832.0000
-Merritt	16303	1	39654943	39654943	39654943	39654943.0000
-sweetish	18001	1	5987435	5987435	5987435	5987435.0000
-dogging	18002	1	28357832	28357832	28357832	28357832.0000
-scornfully	18003	1	39654943	39654943	39654943	39654943.0000
-fetters	18012	1	28357832	28357832	28357832	28357832.0000
-bivalves	18013	1	39654943	39654943	39654943	39654943.0000
-skulking	18021	1	5987435	5987435	5987435	5987435.0000
-flint	18022	1	28357832	28357832	28357832	28357832.0000
-flopping	18023	1	39654943	39654943	39654943	39654943.0000
-Judas	18032	1	28357832	28357832	28357832	28357832.0000
-vacuuming	18033	1	39654943	39654943	39654943	39654943.0000
-medical	18041	1	5987435	5987435	5987435	5987435.0000
-bloodbath	18042	1	28357832	28357832	28357832	28357832.0000
-subschema	18043	1	39654943	39654943	39654943	39654943.0000
-interdependent	18051	1	5987435	5987435	5987435	5987435.0000
-Graves	18052	1	28357832	28357832	28357832	28357832.0000
-neonatal	18053	1	39654943	39654943	39654943	39654943.0000
-sorters	18061	1	5987435	5987435	5987435	5987435.0000
-epistle	18062	1	28357832	28357832	28357832	28357832.0000
-Conley	18101	1	5987435	5987435	5987435	5987435.0000
-lectured	18102	1	28357832	28357832	28357832	28357832.0000
-Abraham	18103	1	39654943	39654943	39654943	39654943.0000
-cage	18201	1	5987435	5987435	5987435	5987435.0000
-hushes	18202	1	28357832	28357832	28357832	28357832.0000
-Simla	18402	1	28357832	28357832	28357832	28357832.0000
-reporters	18403	1	39654943	39654943	39654943	39654943.0000
-coexist	18601	1	5987435	5987435	5987435	5987435.0000
-Beebe	18602	1	28357832	28357832	28357832	28357832.0000
-Taoism	18603	1	39654943	39654943	39654943	39654943.0000
-Connally	18801	1	5987435	5987435	5987435	5987435.0000
-fetched	18802	1	28357832	28357832	28357832	28357832.0000
-checkpoints	18803	1	39654943	39654943	39654943	39654943.0000
-gritty	18811	1	5987435	5987435	5987435	5987435.0000
-firearm	18812	1	28357832	28357832	28357832	28357832.0000
-minima	19101	1	5987435	5987435	5987435	5987435.0000
-Selfridge	19102	1	28357832	28357832	28357832	28357832.0000
-disable	19103	1	39654943	39654943	39654943	39654943.0000
-witchcraft	19201	1	5987435	5987435	5987435	5987435.0000
-betroth	30501	1	5987435	5987435	5987435	5987435.0000
-Manhattanize	30502	1	28357832	28357832	28357832	28357832.0000
-imprint	30503	1	39654943	39654943	39654943	39654943.0000
-swelling	31901	1	5987435	5987435	5987435	5987435.0000
-interrelationships	36001	1	5987435	5987435	5987435	5987435.0000
-riser	36002	1	28357832	28357832	28357832	28357832.0000
-bee	38001	1	5987435	5987435	5987435	5987435.0000
-kanji	38002	1	28357832	28357832	28357832	28357832.0000
-dental	38003	1	39654943	39654943	39654943	39654943.0000
-railway	38011	1	5987435	5987435	5987435	5987435.0000
-validate	38012	1	28357832	28357832	28357832	28357832.0000
-normalizes	38013	1	39654943	39654943	39654943	39654943.0000
-Kline	38101	1	5987435	5987435	5987435	5987435.0000
-Anatole	38102	1	28357832	28357832	28357832	28357832.0000
-partridges	38103	1	39654943	39654943	39654943	39654943.0000
-recruited	38201	1	5987435	5987435	5987435	5987435.0000
-dimensions	38202	1	28357832	28357832	28357832	28357832.0000
-Chicana	38203	1	39654943	39654943	39654943	39654943.0000
-select t3.companynr,fld3,sum(price) from t3,t2 where t2.fld1 = t3.t2nr and t3.companynr = 512 group by companynr,fld3;
-companynr	fld3	sum(price)
-512	boat	786542
-512	capably	786542
-512	cupboard	786542
-512	decliner	786542
-512	descendants	786542
-512	dopers	786542
-512	erases	786542
-512	Micronesia	786542
-512	Miles	786542
-512	skies	786542
-select t2.companynr,count(*),min(fld3),max(fld3),sum(price),avg(price) from t2,t3 where t3.companynr >= 30 and t3.companynr <= 58 and t3.t2nr = t2.fld1 and 1+1=2 group by t2.companynr;
-companynr	count(*)	min(fld3)	max(fld3)	sum(price)	avg(price)
-0	1	Omaha	Omaha	5987435	5987435.0000
-36	1	dubbed	dubbed	28357832	28357832.0000
-37	83	Abraham	Wotan	1908978016	22999735.1325
-50	2	scribbled	tapestry	68012775	34006387.5000
-select t3.companynr+0,t3.t2nr,fld3,sum(price) from t3,t2 where t2.fld1 = t3.t2nr and t3.companynr = 37 group by 1,t3.t2nr,fld3,fld3,fld3,fld3,fld3 order by fld1;
-t3.companynr+0	t2nr	fld3	sum(price)
-37	1	Omaha	5987435
-37	11401	breaking	5987435
-37	11402	Romans	28357832
-37	11403	intercepted	39654943
-37	11501	bewilderingly	5987435
-37	11701	astound	5987435
-37	11702	admonishing	28357832
-37	11703	sumac	39654943
-37	12001	flanking	5987435
-37	12003	combed	39654943
-37	12301	Eulerian	5987435
-37	12302	dubbed	28357832
-37	12303	Kane	39654943
-37	12501	annihilates	5987435
-37	12602	Wotan	28357832
-37	12603	snatching	39654943
-37	12701	grazing	5987435
-37	12702	Baird	28357832
-37	12703	celery	39654943
-37	13601	handgun	5987435
-37	13602	foldout	28357832
-37	13603	mystic	39654943
-37	13801	intelligibility	5987435
-37	13802	Augustine	28357832
-37	13803	teethe	39654943
-37	13901	scholastics	5987435
-37	16001	audiology	5987435
-37	16201	wallet	5987435
-37	16202	parters	28357832
-37	16301	eschew	5987435
-37	16302	quitter	28357832
-37	16303	neat	39654943
-37	18001	jarring	5987435
-37	18002	tinily	28357832
-37	18003	balled	39654943
-37	18012	impulsive	28357832
-37	18013	starlet	39654943
-37	18021	lawgiver	5987435
-37	18022	stated	28357832
-37	18023	readable	39654943
-37	18032	testicle	28357832
-37	18033	Parsifal	39654943
-37	18041	Punjab	5987435
-37	18042	Merritt	28357832
-37	18043	Quixotism	39654943
-37	18051	sureties	5987435
-37	18052	puddings	28357832
-37	18053	tapestry	39654943
-37	18061	trimmings	5987435
-37	18062	humility	28357832
-37	18101	tragedies	5987435
-37	18102	skulking	28357832
-37	18103	flint	39654943
-37	18201	relaxing	5987435
-37	18202	offload	28357832
-37	18402	suites	28357832
-37	18403	lists	39654943
-37	18601	vacuuming	5987435
-37	18602	dentally	28357832
-37	18603	humanness	39654943
-37	18801	inch	5987435
-37	18802	Weissmuller	28357832
-37	18803	irresponsibly	39654943
-37	18811	repetitions	5987435
-37	18812	Antares	28357832
-37	19101	ventilate	5987435
-37	19102	pityingly	28357832
-37	19103	interdependent	39654943
-37	19201	Graves	5987435
-37	30501	neonatal	5987435
-37	30502	scribbled	28357832
-37	30503	chafe	39654943
-37	31901	realtor	5987435
-37	36001	elite	5987435
-37	36002	funereal	28357832
-37	38001	Conley	5987435
-37	38002	lectured	28357832
-37	38003	Abraham	39654943
-37	38011	groupings	5987435
-37	38012	dissociate	28357832
-37	38013	coexist	39654943
-37	38101	rusting	5987435
-37	38102	galling	28357832
-37	38103	obliterates	39654943
-37	38201	resumes	5987435
-37	38202	analyzable	28357832
-37	38203	terminator	39654943
-select sum(price) from t3,t2 where t2.fld1 = t3.t2nr and t3.companynr = 512 and t3.t2nr = 38008 and t2.fld1 = 38008 or t2.fld1= t3.t2nr and t3.t2nr = 38008 and t2.fld1 = 38008;
-sum(price)
-234298
-select t2.fld1,sum(price) from t3,t2 where t2.fld1 = t3.t2nr and t3.companynr = 512 and t3.t2nr = 38008 and t2.fld1 = 38008 or t2.fld1 = t3.t2nr and t3.t2nr = 38008 and t2.fld1 = 38008 or t3.t2nr = t2.fld1 and t2.fld1 = 38008 group by t2.fld1;
-fld1	sum(price)
-38008	234298
-explain select fld3 from t2 where 1>2 or 2>3;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	NULL	NULL	NULL	NULL	NULL	NULL	#	Impossible WHERE
-explain select fld3 from t2 where fld1=fld1;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	ALL	NULL	NULL	NULL	NULL	#	
-select companynr,fld1 from t2 HAVING fld1=250501 or fld1=250502;
-companynr	fld1
-34	250501
-34	250502
-select companynr,fld1 from t2 WHERE fld1>=250501 HAVING fld1<=250502;
-companynr	fld1
-34	250501
-34	250502
-select companynr,count(*) as count,sum(fld1) as sum from t2 group by companynr having count > 40 and sum/count >= 120000;
-companynr	count	sum
-0	82	10355753
-29	95	14473298
-34	70	17788966
-37	588	83602098
-41	52	12816335
-select companynr from t2 group by companynr having count(*) > 40 and sum(fld1)/count(*) >= 120000 ;
-companynr
-0
-29
-34
-37
-41
-select t2.companynr,companyname,count(*) from t2,t4 where t2.companynr=t4.companynr group by companyname having t2.companynr >= 40;
-companynr	companyname	count(*)
-68	company 10	12
-50	company 11	11
-40	company 5	37
-41	company 6	52
-53	company 7	4
-58	company 8	23
-65	company 9	10
-select count(*) from t2;
-count(*)
-1199
-select count(*) from t2 where fld1 < 098024;
-count(*)
-387
-select min(fld1) from t2 where fld1>= 098024;
-min(fld1)
-98024
-select max(fld1) from t2 where fld1>= 098024;
-max(fld1)
-1232609
-select count(*) from t3 where price2=76234234;
-count(*)
-4181
-select count(*) from t3 where companynr=512 and price2=76234234;
-count(*)
-4181
-explain select min(fld1),max(fld1),count(*) from t2;
-id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
-1	SIMPLE	t2	index	NULL	PRIMARY	4	NULL	#	
-select min(fld1),max(fld1),count(*) from t2;
-min(fld1)	max(fld1)	count(*)
-0	1232609	1199
-select min(t2nr),max(t2nr) from t3 where t2nr=2115 and price2=823742;
-min(t2nr)	max(t2nr)
-2115	2115
-select count(*),min(t2nr),max(t2nr) from t3 where name='spates' and companynr=78;
-count(*)	min(t2nr)	max(t2nr)
-4181	4	41804
-select t2nr,count(*) from t3 where name='gems' group by t2nr limit 20;
-t2nr	count(*)
-9	1
-19	1
-29	1
-39	1
-49	1
-59	1
-69	1
-79	1
-89	1
-99	1
-109	1
-119	1
-129	1
-139	1
-149	1
-159	1
-169	1
-179	1
-189	1
-199	1
-select max(t2nr) from t3 where price=983543950;
-max(t2nr)
-41807
-select t1.period from t3 = t1 limit 1;
-period
-1001
-select t1.period from t1 as t1 limit 1;
-period
-9410
-select t1.period as "Nuvarande period" from t1 as t1 limit 1;
-Nuvarande period
-9410
-select period as ok_period from t1 limit 1;
-ok_period
-9410
-select period as ok_period from t1 group by ok_period limit 1;
-ok_period
-9410
-select 1+1 as summa from t1 group by summa limit 1;
-summa
-2
-select period as "Nuvarande period" from t1 group by "Nuvarande period" limit 1;
-Nuvarande period
-9410
-show tables;
-Tables_in_test
-t1
-t2
-t3
-show tables from test like "s%";
-Tables_in_test (s%)
-show tables from test like "t?";
-Tables_in_test (t?)
-show full columns from t2;
-Field	Type	Collation	Null	Key	Default	Extra	Privileges	Comment
-auto	int	NULL	NO	PRI	NULL	auto_increment	#	
-fld1	int	NULL	NO	UNI	0		#	
-companynr	int	NULL	NO		0		#	
-fld3	varchar(30)	utf8_general_ci	NO	MUL			#	
-fld4	varchar(35)	utf8_general_ci	NO				#	
-fld5	varchar(35)	utf8_general_ci	NO				#	
-fld6	varchar(4)	utf8_general_ci	NO				#	
-show full columns from t2 from test like 'f%';
-Field	Type	Collation	Null	Key	Default	Extra	Privileges	Comment
-fld1	int	NULL	NO	UNI	0		#	
-fld3	varchar(30)	utf8_general_ci	NO	MUL			#	
-fld4	varchar(35)	utf8_general_ci	NO				#	
-fld5	varchar(35)	utf8_general_ci	NO				#	
-fld6	varchar(4)	utf8_general_ci	NO				#	
-show full columns from t2 from test like 's%';
-Field	Type	Collation	Null	Key	Default	Extra	Privileges	Comment
-show keys from t2;
-Table	Non_unique	Key_name	Seq_in_index	Column_name	Collation	Cardinality	Sub_part	Packed	Null	Index_type	Comment	Index_Comment
-t2	0	PRIMARY	1	auto	A	#	NULL	NULL		BTREE		
-t2	0	fld1	1	fld1	A	#	NULL	NULL		BTREE		
-t2	1	fld3	1	fld3	A	#	NULL	NULL		BTREE		
-drop table t4, t3, t2, t1;
-CREATE TEMPORARY TABLE t1 (
-cont_nr int NOT NULL auto_increment,
-ver_nr int NOT NULL default '0',
-aufnr int NOT NULL default '0',
-username varchar(50) NOT NULL default '',
-hdl_nr int NOT NULL default '0',
-eintrag date NULL,
-st_klasse varchar(40) NOT NULL default '',
-st_wert varchar(40) NOT NULL default '',
-st_zusatz varchar(40) NOT NULL default '',
-st_bemerkung varchar(255) NOT NULL default '',
-kunden_art varchar(40) NOT NULL default '',
-mcbs_knr int default NULL,
-mcbs_aufnr int NOT NULL default '0',
-schufa_status char(1) default '?',
-bemerkung text,
-wirknetz text,
-wf_igz int NOT NULL default '0',
-tarifcode varchar(80) default NULL,
-recycle char(1) default NULL,
-sim varchar(30) default NULL,
-mcbs_tpl varchar(30) default NULL,
-emp_nr int NOT NULL default '0',
-laufzeit int default NULL,
-hdl_name varchar(30) default NULL,
-prov_hdl_nr int NOT NULL default '0',
-auto_wirknetz varchar(50) default NULL,
-auto_billing varchar(50) default NULL,
-touch timestamp NOT NULL,
-kategorie varchar(50) default NULL,
-kundentyp varchar(20) NOT NULL default '',
-sammel_rech_msisdn varchar(30) NOT NULL default '',
-p_nr varchar(9) NOT NULL default '',
-suffix char(3) NOT NULL default '',
-PRIMARY KEY (cont_nr),
-KEY idx_aufnr(aufnr),
-KEY idx_hdl_nr(hdl_nr),
-KEY idx_st_klasse(st_klasse),
-KEY ver_nr(ver_nr),
-KEY eintrag_idx(eintrag),
-KEY emp_nr_idx(emp_nr),
-KEY wf_igz(wf_igz),
-KEY touch(touch),
-KEY hdl_tag(eintrag,hdl_nr),
-KEY prov_hdl_nr(prov_hdl_nr),
-KEY mcbs_aufnr(mcbs_aufnr),
-KEY kundentyp(kundentyp),
-KEY p_nr(p_nr,suffix)
-) ENGINE=MyISAM;
-INSERT INTO t1 VALUES (3359356,405,3359356,'Mustermann Musterfrau',52500,'2000-05-20','workflow','Auftrag erledigt','Originalvertrag eingegangen und geprüft','','privat',1485525,2122316,'+','','N',1909160,'MobilComSuper92000D2',NULL,NULL,'MS9ND2',3,24,'MobilCom Shop Koeln',52500,NULL,'auto',20010202105916,'Mobilfunk','PP','','','');
-INSERT INTO t1 VALUES (3359357,468,3359357,'Mustermann Musterfrau',7001,'2000-05-20','workflow','Auftrag erledigt','Originalvertrag eingegangen und geprüft','','privat',1503580,2139699,'+','','P',1909171,'MobilComSuper9D1T10SFreisprech(Akquise)',NULL,NULL,'MS9NS1',327,24,'MobilCom Intern',7003,NULL,'auto',20010202105916,'Mobilfunk','PP','','','');
-INSERT INTO t1 VALUES (3359358,407,3359358,'Mustermann Musterfrau',7001,'2000-05-20','workflow','Auftrag erledigt','Originalvertrag eingegangen und geprüft','','privat',1501358,2137473,'N','','N',1909159,'MobilComSuper92000D2',NULL,NULL,'MS9ND2',325,24,'MobilCom Intern',7003,NULL,'auto',20010202105916,'Mobilfunk','PP','','','');
-INSERT INTO t1 VALUES (3359359,468,3359359,'Mustermann Musterfrau',7001,'2000-05-20','workflow','Auftrag erledigt','Originalvertrag eingegangen und geprüft','','privat',1507831,2143894,'+','','P',1909162,'MobilComSuper9D1T10SFreisprech(Akquise)',NULL,NULL,'MS9NS1',327,24,'MobilCom Intern',7003,NULL,'auto',20010202105916,'Mobilfunk','PP','','','');
-INSERT INTO t1 VALUES (3359360,0,0,'Mustermann Musterfrau',29674907,'2000-05-20','workflow','Auftrag erledigt','Originalvertrag eingegangen und geprüft','','privat',1900169997,2414578,'+',NULL,'N',1909148,'',NULL,NULL,'RV99066_2',20,NULL,'POS',29674907,NULL,NULL,20010202105916,'Mobilfunk','','','97317481','007');
-INSERT INTO t1 VALUES (3359361,406,3359361,'Mustermann Musterfrau',7001,'2000-05-20','workflow','Auftrag storniert','','(7001-84):Storno, Kd. möchte nicht mehr','privat',NULL,0,'+','','P',1909150,'MobilComSuper92000D1(Akquise)',NULL,NULL,'MS9ND1',325,24,'MobilCom Intern',7003,NULL,'auto',20010202105916,'Mobilfunk','PP','','','');
-INSERT INTO t1 VALUES (3359362,406,3359362,'Mustermann Musterfrau',7001,'2000-05-20','workflow','Auftrag erledigt','Originalvertrag eingegangen und geprüft','','privat',1509984,2145874,'+','','P',1909154,'MobilComSuper92000D1(Akquise)',NULL,NULL,'MS9ND1',327,24,'MobilCom Intern',7003,NULL,'auto',20010202105916,'Mobilfunk','PP','','','');
-SELECT ELT(FIELD(kundentyp,'PP','PPA','PG','PGA','FK','FKA','FP','FPA','K','KA','V','VA',''), 'Privat (Private Nutzung)','Privat (Private Nutzung) Sitz im Ausland','Privat (geschaeftliche Nutzung)','Privat (geschaeftliche Nutzung) Sitz im Ausland','Firma (Kapitalgesellschaft)','Firma (Kapitalgesellschaft) Sitz im Ausland','Firma (Personengesellschaft)','Firma (Personengesellschaft) Sitz im Ausland','oeff. rechtl. Koerperschaft','oeff. rechtl. Koerperschaft Sitz im Ausland','Eingetragener Verein','Eingetragener Verein Sitz im Ausland','Typ unbekannt') AS Kundentyp ,kategorie FROM t1 WHERE hdl_nr < 2000000 AND kategorie IN ('Prepaid','Mobilfunk') AND st_klasse = 'Workflow' GROUP BY kundentyp ORDER BY kategorie;
-Kundentyp	kategorie
-Privat (Private Nutzung)	Mobilfunk
-Warnings:
-Warning	1052	Column 'kundentyp' in group statement is ambiguous
-drop table t1;

=== removed directory 'plugin/pool_of_threads/tests/t'
=== removed file 'plugin/pool_of_threads/tests/t/master.opt'
--- plugin/pool_of_threads/tests/t/master.opt	2010-09-15 20:24:31 +0000
+++ plugin/pool_of_threads/tests/t/master.opt	1970-01-01 00:00:00 +0000
@@ -1,1 +0,0 @@
---plugin-add=pool_of_threads

=== removed file 'plugin/pool_of_threads/tests/t/pool_of_threads-master.opt'
--- plugin/pool_of_threads/tests/t/pool_of_threads-master.opt	2010-08-19 18:07:50 +0000
+++ plugin/pool_of_threads/tests/t/pool_of_threads-master.opt	1970-01-01 00:00:00 +0000
@@ -1,1 +0,0 @@
---plugin-add=pool_of_threads --scheduler=pool_of_threads

=== removed file 'plugin/pool_of_threads/tests/t/pool_of_threads.test'
--- plugin/pool_of_threads/tests/t/pool_of_threads.test	2009-11-12 00:44:38 +0000
+++ plugin/pool_of_threads/tests/t/pool_of_threads.test	1970-01-01 00:00:00 +0000
@@ -1,16 +0,0 @@
-# 
-# Verify that the single_thread scheduler actually can process queries
-#
-
-select PLUGIN_NAME from information_schema.plugins where is_active="YES" and plugin_type="Scheduler";
-
---disable_warnings
-DROP TABLE IF EXISTS t1;
---enable_warnings
-CREATE TABLE t1
-(
-  some_text VARCHAR(100) NOT NULL
-);
-INSERT INTO t1 VALUES ("I love testing");
-SELECT some_text FROM t1;
-DROP TABLE t1;

=== modified file 'plugin/show_schema_proto/tests/r/basic.result'
--- plugin/show_schema_proto/tests/r/basic.result	2010-03-16 23:42:10 +0000
+++ plugin/show_schema_proto/tests/r/basic.result	2010-10-14 18:58:48 +0000
@@ -1,2 +1,2 @@
 SELECT SHOW_SCHEMA_PROTO('not_exists');
-ERROR 42000: Unknown database 'not_exists'
+ERROR 42000: Unknown schema 'not_exists'

=== modified file 'plugin/simple_user_policy/tests/r/basic.result'
--- plugin/simple_user_policy/tests/r/basic.result	2010-04-15 19:26:37 +0000
+++ plugin/simple_user_policy/tests/r/basic.result	2010-10-14 18:58:48 +0000
@@ -19,11 +19,11 @@
 INFORMATION_SCHEMA
 user1
 SELECT * from user2.dont_exist;
-ERROR 42000: Access denied for user 'user1'@'LOCALHOST' to database 'user2'
+ERROR 42000: Access denied for user 'user1'@'LOCALHOST' to schema 'user2'
 create database authorize_fail;
-ERROR 42000: Access denied for user 'user1'@'LOCALHOST' to database 'authorize_fail'
+ERROR 42000: Access denied for user 'user1'@'LOCALHOST' to schema 'authorize_fail'
 drop database user2;
-ERROR 42000: Access denied for user 'user1'@'LOCALHOST' to database 'user2'
+ERROR 42000: Access denied for user 'user1'@'LOCALHOST' to schema 'user2'
 create table t1 (kill_id int);
 insert into t1 values(connection_id());
 show processlist;
@@ -67,6 +67,6 @@
 @id != connection_id()
 1
 connect(localhost,authz,,authz_no,MASTER_PORT,);
-ERROR 42000: Access denied for user 'authz'@'LOCALHOST' to database 'authz_no'
+ERROR 42000: Access denied for user 'authz'@'LOCALHOST' to schema 'authz_no'
 drop schema user1;
 drop schema user2;

=== removed directory 'plugin/single_thread'
=== removed file 'plugin/single_thread/plugin.ini'
--- plugin/single_thread/plugin.ini	2010-09-15 20:24:31 +0000
+++ plugin/single_thread/plugin.ini	1970-01-01 00:00:00 +0000
@@ -1,8 +0,0 @@
-[plugin]
-headers=single_thread.h
-title=Single Thread Scheduler
-description=Single Thread Scheduler
-load_by_default=no
-static=no
-#uncomment when single_thread shutdown is fixed
-testsuite=disable

=== removed file 'plugin/single_thread/single_thread.cc'
--- plugin/single_thread/single_thread.cc	2010-05-18 18:20:56 +0000
+++ plugin/single_thread/single_thread.cc	1970-01-01 00:00:00 +0000
@@ -1,46 +0,0 @@
-/* Copyright (C) 2006 MySQL AB
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
-
-#include "config.h"
-#include <plugin/single_thread/single_thread.h>
-
-using namespace std;
-using namespace drizzled;
-
-
-/* Global's (TBR) */
-static SingleThreadScheduler *scheduler= NULL;
-
-
-static int init(module::Context &context)
-{
-  scheduler= new SingleThreadScheduler("single_thread");
-  context.add(scheduler);
-  return 0;
-}
-
-DRIZZLE_DECLARE_PLUGIN
-{
-  DRIZZLE_VERSION_ID,
-  "single_thread",
-  "0.1",
-  "Brian Aker",
-  "Single Thread Scheduler",
-  PLUGIN_LICENSE_GPL,
-  init, /* Plugin Init */
-  NULL,   /* system variables */
-  NULL    /* config options */
-}
-DRIZZLE_DECLARE_PLUGIN_END;

=== removed file 'plugin/single_thread/single_thread.h'
--- plugin/single_thread/single_thread.h	2010-08-09 00:00:11 +0000
+++ plugin/single_thread/single_thread.h	1970-01-01 00:00:00 +0000
@@ -1,66 +0,0 @@
-/* Copyright (C) 2009 Sun Microsystems
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
-
-#ifndef PLUGIN_SINGLE_THREAD_SINGLE_THREAD_H
-#define PLUGIN_SINGLE_THREAD_SINGLE_THREAD_H
-
-#include <drizzled/gettext.h>
-#include <drizzled/error.h>
-#include <drizzled/plugin/scheduler.h>
-#include <drizzled/sql_parse.h>
-#include <drizzled/session.h>
-#include <string>
-#include "drizzled/internal/my_sys.h"
-
-
-/**
- * Simple scheduler that uses the main thread to handle the request. This
- * should only be used for debugging.
- */
-class SingleThreadScheduler : public drizzled::plugin::Scheduler
-{
-public:
-  SingleThreadScheduler(const char *name_arg) : 
-    Scheduler(name_arg) {}
-
-  /* When we enter this function, LOCK_thread_count is held! */
-  virtual bool addSession(drizzled::Session *session)
-  {
-    if (drizzled::internal::my_thread_init())
-    {
-      session->disconnect(drizzled::ER_OUT_OF_RESOURCES, true);
-      session->status_var.aborted_connects++;
-      return true;
-    }
-
-    /*
-      This is not the real thread start beginning, but there is not an easy
-      way to find it.
-    */
-    session->thread_stack= (char *)&session;
-
-    session->run();
-    killSessionNow(session);
-    return false;
-  }
-
-  virtual void killSessionNow(drizzled::Session *session)
-  {
-    drizzled::Session::unlink(session);
-    drizzled::internal::my_thread_end();
-  }
-};
-
-#endif /* PLUGIN_SINGLE_THREAD_SINGLE_THREAD_H */

=== removed directory 'plugin/single_thread/tests'
=== removed directory 'plugin/single_thread/tests/r'
=== removed file 'plugin/single_thread/tests/r/single_thread.result'
--- plugin/single_thread/tests/r/single_thread.result	2009-11-12 00:44:37 +0000
+++ plugin/single_thread/tests/r/single_thread.result	1970-01-01 00:00:00 +0000
@@ -1,13 +0,0 @@
-select PLUGIN_NAME from information_schema.plugins where is_active="YES" and plugin_type="Scheduler";
-PLUGIN_NAME
-single_thread
-DROP TABLE IF EXISTS t1;
-CREATE TABLE t1
-(
-some_text VARCHAR(100) NOT NULL
-);
-INSERT INTO t1 VALUES ("I love testing");
-SELECT some_text FROM t1;
-some_text
-I love testing
-DROP TABLE t1;

=== removed directory 'plugin/single_thread/tests/t'
=== removed file 'plugin/single_thread/tests/t/master.opt'
--- plugin/single_thread/tests/t/master.opt	2010-09-15 20:24:31 +0000
+++ plugin/single_thread/tests/t/master.opt	1970-01-01 00:00:00 +0000
@@ -1,1 +0,0 @@
---plugin-add=single_thread

=== removed file 'plugin/single_thread/tests/t/single_thread-master.opt'
--- plugin/single_thread/tests/t/single_thread-master.opt	2010-08-19 18:07:50 +0000
+++ plugin/single_thread/tests/t/single_thread-master.opt	1970-01-01 00:00:00 +0000
@@ -1,1 +0,0 @@
---plugin-add=single_thread --scheduler=single_thread

=== removed file 'plugin/single_thread/tests/t/single_thread.test'
--- plugin/single_thread/tests/t/single_thread.test	2009-11-12 00:44:37 +0000
+++ plugin/single_thread/tests/t/single_thread.test	1970-01-01 00:00:00 +0000
@@ -1,16 +0,0 @@
-# 
-# Verify that the single_thread scheduler actually can process queries
-#
-
-select PLUGIN_NAME from information_schema.plugins where is_active="YES" and plugin_type="Scheduler";
-
---disable_warnings
-DROP TABLE IF EXISTS t1;
---enable_warnings
-CREATE TABLE t1
-(
-  some_text VARCHAR(100) NOT NULL
-);
-INSERT INTO t1 VALUES ("I love testing");
-SELECT some_text FROM t1;
-DROP TABLE t1;

=== modified file 'po/POTFILES.in'
--- po/POTFILES.in	2010-10-07 17:41:25 +0000
+++ po/POTFILES.in	2010-10-14 18:58:48 +0000
@@ -82,13 +82,9 @@
 plugin/myisam/my_handler_errors.cc
 plugin/mysql_protocol/mysql_protocol.cc
 plugin/pbms/src/parameters_ms.cc
-plugin/pool_of_threads/pool_of_threads.cc
-plugin/pool_of_threads/pool_of_threads.h
-plugin/pool_of_threads/session_scheduler.cc
 plugin/rabbitmq/rabbitmq_log.cc
 plugin/session_dictionary/processlist.cc
 plugin/signal_handler/signal_handler.cc
-plugin/single_thread/single_thread.h
 plugin/syslog/errmsg.cc
 plugin/syslog/function.cc
 plugin/syslog/logging.cc

=== modified file 'tests/r/alter_table.result'
--- tests/r/alter_table.result	2010-09-02 18:35:05 +0000
+++ tests/r/alter_table.result	2010-10-14 18:58:48 +0000
@@ -516,7 +516,7 @@
 use mysqltest;
 drop database mysqltest;
 alter table test.t1 rename t1;
-ERROR 3D000: No database selected
+ERROR 3D000: No schema selected
 alter table test.t1 rename test.t1;
 use test;
 drop table t1;

=== modified file 'tests/r/bigint.result'
--- tests/r/bigint.result	2010-09-02 18:35:05 +0000
+++ tests/r/bigint.result	2010-10-14 18:58:48 +0000
@@ -183,7 +183,7 @@
 drop table t1;
 DROP DATABASE IF EXISTS `scott`;
 Warnings:
-Note	1008	Can't drop database 'scott'; database doesn't exist
+Note	1008	Can't drop schema 'scott'; schema doesn't exist
 create table t1 (a char(100), b varchar(100), c text, d blob);
 insert into t1 values(
 18446744073709551615,18446744073709551615,

=== modified file 'tests/r/connect.result'
--- tests/r/connect.result	2008-12-24 01:49:53 +0000
+++ tests/r/connect.result	2010-10-14 18:58:48 +0000
@@ -4,21 +4,21 @@
 show tables;
 Tables_in_test
 connect(localhost,root,z,test2,MASTER_PORT,);
-ERROR 42000: Unknown database 'test2'
+ERROR 42000: Unknown schema 'test2'
 show tables;
 Tables_in_mysql
 show tables;
 Tables_in_test
 connect(localhost,test,,test2,MASTER_PORT,);
-ERROR 42000: Unknown database 'test2'
+ERROR 42000: Unknown schema 'test2'
 connect(localhost,test,,"",MASTER_PORT,);
-ERROR 42000: Unknown database '""'
+ERROR 42000: Unknown schema '""'
 connect(localhost,test,zorro,test2,MASTER_PORT,);
-ERROR 42000: Unknown database 'test2'
+ERROR 42000: Unknown schema 'test2'
 connect(localhost,test,,test2,MASTER_PORT,);
-ERROR 42000: Unknown database 'test2'
+ERROR 42000: Unknown schema 'test2'
 connect(localhost,test,zorro,test2,MASTER_PORT,);
-ERROR 42000: Unknown database 'test2'
+ERROR 42000: Unknown schema 'test2'
 create table t1 (id integer not null auto_increment primary key);
 create temporary table t2(id integer not null auto_increment primary key);
 set @id := 1;

=== modified file 'tests/r/create.result'
--- tests/r/create.result	2010-10-09 04:44:38 +0000
+++ tests/r/create.result	2010-10-14 18:58:48 +0000
@@ -36,7 +36,7 @@
 create temporary table t1 (ordid int not null auto_increment, ord  varchar(50) not null, primary key (ord,ordid)) engine=MEMORY;
 ERROR 42000: Incorrect table definition; there can be only one auto column and it must be defined as a key
 create table not_existing_database.test (a int);
-ERROR 42000: Unknown database 'not_existing_database'
+ERROR 42000: Unknown schema 'not_existing_database'
 create table `a/a` (a int);
 show create table `a/a`;
 Table	Create Table
@@ -86,7 +86,7 @@
 drop table t1;
 drop database if exists mysqltest;
 Warnings:
-Note	1008	Can't drop database 'mysqltest'; database doesn't exist
+Note	1008	Can't drop schema 'mysqltest'; schema doesn't exist
 create database mysqltest;
 create table mysqltest.$test1 (a$1 int, $b int, c$ int);
 insert into mysqltest.$test1 values (1,2,3);
@@ -290,7 +290,7 @@
 create table `t1 `(a int);
 ERROR 42000: Incorrect table name 't1 '
 create database `db1 `;
-ERROR 42000: Incorrect database name 'db1 '
+ERROR 42000: Incorrect schema name 'db1 '
 create table t1(`a ` int);
 ERROR 42000: Incorrect column name 'a '
 create table t1 (a int,);
@@ -366,7 +366,7 @@
 create table t3 like mysqltest.t3;
 ERROR 42S01: Table 't3' already exists
 create table non_existing_database.t1 like t1;
-ERROR 42000: Unknown database 'non_existing_database'
+ERROR 42000: Unknown schema 'non_existing_database'
 create table t3 like non_existing_table;
 ERROR 42S02: Table 'test.non_existing_table' doesn't exist
 create temporary table t3 like t1;
@@ -524,7 +524,7 @@
 create table t1(test.column.name int);
 ERROR 42000: Incorrect table name 'column'
 create table t1(xyz.t1.name int);
-ERROR 42000: Incorrect database name 'xyz'
+ERROR 42000: Incorrect schema name 'xyz'
 create table t1(t1.name int);
 create table t2(test.t2.name int);
 drop table t1,t2;
@@ -543,12 +543,12 @@
 use mysqltest;
 drop database mysqltest;
 create table test.t1 like x;
-ERROR 3D000: No database selected
+ERROR 3D000: No schema selected
 drop table if exists test.t1;
 create database mysqltest;
 create database if not exists mysqltest;
 Warnings:
-Note	1007	Can't create database 'mysqltest'; database exists
+Note	1007	Can't create schema 'mysqltest'; schema exists
 show create database mysqltest;
 Database	Create Database
 mysqltest	CREATE DATABASE `mysqltest` COLLATE = utf8_general_ci
@@ -1399,11 +1399,11 @@
 a	b
 drop table t1,t2;
 CREATE DATABASE aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa;
-ERROR 42000: Incorrect database name 'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'
+ERROR 42000: Incorrect schema name 'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'
 DROP DATABASE aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa;
-ERROR 42000: Incorrect database name 'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'
+ERROR 42000: Incorrect schema name 'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'
 USE aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa;
-ERROR 42000: Incorrect database name 'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'
+ERROR 42000: Incorrect schema name 'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'
 SHOW CREATE DATABASE aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa;
 Database	Create Database
 create database имя_базы_в_кодировке_утф8_длиной_больше_чем_45;

=== modified file 'tests/r/data_dictionary_like_info.result'
--- tests/r/data_dictionary_like_info.result	2010-10-09 01:10:07 +0000
+++ tests/r/data_dictionary_like_info.result	2010-10-14 18:58:48 +0000
@@ -153,7 +153,7 @@
 use data_dictionary;
 use data_dictionary;
 create temporary table schemas(f1 char(10));
-ERROR 42000: Access denied for user ''@'' to database 'data_dictionary'
+ERROR 42000: Access denied for user ''@'' to schema 'data_dictionary'
 use test;
 create table t1(id int);
 insert into t1(id) values (1);

=== modified file 'tests/r/drizzle_client.result'
--- tests/r/drizzle_client.result	2010-07-12 06:26:42 +0000
+++ tests/r/drizzle_client.result	2010-10-14 18:58:48 +0000
@@ -104,8 +104,8 @@
 Test connect with dbname only => new dbname, old hostname
 ERROR 1064 (42000) at line 2: You have an error in your SQL syntax; check the manual that corresponds to your Drizzle server version for the right syntax to use near 'connecttest' at line 1
 Test connect with _invalid_ dbname only => new invalid dbname, old hostname
-ERROR 1049 (42000): Unknown database 'invalid'
-ERROR 1049 (42000): Unknown database 'invalid'
+ERROR 1049 (42000): Unknown schema 'invalid'
+ERROR 1049 (42000): Unknown schema 'invalid'
 Test connect with dbname + hostname
 Test connect with dbname + _invalid_ hostname
 End of 5.0 tests

=== modified file 'tests/r/drop.result'
--- tests/r/drop.result	2010-03-31 19:14:14 +0000
+++ tests/r/drop.result	2010-10-14 18:58:48 +0000
@@ -63,7 +63,7 @@
 mysql
 test
 drop database mysqltest;
-ERROR HY000: Can't drop database 'mysqltest'; database doesn't exist
+ERROR HY000: Can't drop schema 'mysqltest'; schema doesn't exist
 drop table t1;
 flush tables with read lock;
 create table t1(n int);

=== modified file 'tests/r/func_str.result'
--- tests/r/func_str.result	2010-10-07 21:44:19 +0000
+++ tests/r/func_str.result	2010-10-14 18:58:48 +0000
@@ -718,7 +718,7 @@
 1      
 drop table t1;
 select load_file("lkjlkj");
-ERROR HY000: The file 'lkjlkj' must be in the database directory or be readable by all
+ERROR HY000: The file 'lkjlkj' must be in the schema directory or be readable by all
 CREATE TABLE t1 (a varchar(10));
 INSERT INTO t1 VALUES ('abc'), ('xyz');
 SELECT a, CONCAT(a,' ',a) AS c FROM t1

=== modified file 'tests/r/lock_multi.result'
--- tests/r/lock_multi.result	2010-03-18 01:23:59 +0000
+++ tests/r/lock_multi.result	2010-10-14 18:58:48 +0000
@@ -6,5 +6,5 @@
 ERROR HY000: Can't execute the query because you have a conflicting read lock
 UNLOCK TABLES;
 DROP DATABASE mysqltest_1;
-ERROR HY000: Can't drop database 'mysqltest_1'; database doesn't exist
+ERROR HY000: Can't drop schema 'mysqltest_1'; schema doesn't exist
 End of 5.1 tests

=== modified file 'tests/r/lowercase_fs_off.result'
--- tests/r/lowercase_fs_off.result	2010-03-31 05:53:34 +0000
+++ tests/r/lowercase_fs_off.result	2010-10-14 18:58:48 +0000
@@ -4,6 +4,6 @@
 d1
 create database d2;
 create database D1;
-ERROR HY000: Can't create database 'D1'; database exists
+ERROR HY000: Can't create schema 'D1'; schema exists
 drop database d2;
 drop database d1;

=== modified file 'tests/r/outfile.result'
--- tests/r/outfile.result	2010-10-05 20:43:06 +0000
+++ tests/r/outfile.result	2010-10-14 18:58:48 +0000
@@ -17,7 +17,7 @@
 ERROR HY000: File '../../tmp/outfile-test.2' already exists
 ERROR HY000: File '../../tmp/outfile-test.3' already exists
 select load_file(concat(@tmpdir,"/outfile-test.not-exist"));
-ERROR HY000: The file '../../tmp/outfile-test.not-exist' must be in the database directory or be readable by all
+ERROR HY000: The file '../../tmp/outfile-test.not-exist' must be in the schema directory or be readable by all
 drop table t1;
 select load_file(concat(@tmpdir,"/outfile-test.4"));
 load_file(concat(@tmpdir,"/outfile-test.4"))

=== modified file 'tests/r/show_check.result'
--- tests/r/show_check.result	2010-09-02 18:35:05 +0000
+++ tests/r/show_check.result	2010-10-14 18:58:48 +0000
@@ -470,10 +470,10 @@
 ) ENGINE=DEFAULT COLLATE = utf8_general_ci
 DROP TABLE t1;
 SHOW TABLES FROM non_existing_database;
-ERROR 42000: Unknown database 'non_existing_database'
+ERROR 42000: Unknown schema 'non_existing_database'
 End of 4.1 tests
 SHOW TABLES FROM no_such_database;
-ERROR 42000: Unknown database 'no_such_database'
+ERROR 42000: Unknown schema 'no_such_database'
 SHOW COLUMNS FROM no_such_table;
 ERROR 42S02: Table 'test.no_such_table' doesn't exist
 show variables like 'myisam_recover_options';

=== modified file 'tests/r/statement_boundaries.result'
--- tests/r/statement_boundaries.result	2010-03-18 01:23:59 +0000
+++ tests/r/statement_boundaries.result	2010-10-14 18:58:48 +0000
@@ -8,7 +8,7 @@
 Handler_commit	0
 DROP SCHEMA IF EXISTS boundaries;
 Warnings:
-Note	1008	Can't drop database 'boundaries'; database doesn't exist
+Note	1008	Can't drop schema 'boundaries'; schema doesn't exist
 SHOW STATUS LIKE 'Handler_commit%';
 Variable_name	Value
 Handler_commit	1
@@ -23,7 +23,7 @@
 BEGIN;
 DROP SCHEMA IF EXISTS boundaries;
 Warnings:
-Note	1008	Can't drop database 'boundaries'; database doesn't exist
+Note	1008	Can't drop schema 'boundaries'; schema doesn't exist
 COMMIT;
 SHOW STATUS LIKE 'Handler_commit%';
 Variable_name	Value

=== modified file 'tests/r/warnings.result'
--- tests/r/warnings.result	2010-09-23 01:53:13 +0000
+++ tests/r/warnings.result	2010-10-14 18:58:48 +0000
@@ -43,7 +43,7 @@
 Note	1051	Unknown table 'not_exists_table'
 drop database if exists not_exists_db;
 Warnings:
-Note	1008	Can't drop database 'not_exists_db'; database doesn't exist
+Note	1008	Can't drop schema 'not_exists_db'; schema doesn't exist
 show count(*) warnings;
 @@session.warning_count
 1

